@@ -26,11 +26,11 @@
 #include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiocodec/ADM_audiocodec.h"
 #include "ADM_audiofilter/audiofilter_channel_route.h"
-
+#include "ADM_libraries/ADM_libwrapper/libwrapper_global.h"
 
 ADM_Audiocodec	*getAudioCodec(uint32_t fourcc,WAVHeader *info,uint32_t extra,uint8_t *extraData)
 {
-ADM_Audiocodec *out;
+ADM_Audiocodec *out = NULL;
 
 		// fake codec for 8 bits
 		if(fourcc==WAV_PCM)
@@ -44,10 +44,18 @@ ADM_Audiocodec *out;
 			}
  		switch(fourcc)
    			{
+                                case WAV_NELLYMOSER:
+                                        printf("\n Audio codec:  NELLYMOSER\n");
+                                        out= (ADM_Audiocodec *)new ADM_AudiocodecWMA(fourcc,info,extra,extraData);
+                                        break;
                                 case WAV_IMAADPCM:
                                         printf("\n Audio codec:  IMA MS ADPCM\n");
                                         out= (ADM_Audiocodec *)new ADM_AudiocodecImaAdpcm(fourcc,info);
                                         break;
+                                case WAV_MSADPCM:
+                                        printf("\n Audio codec:   MS ADPCM\n");
+                                        out= (ADM_Audiocodec *)new ADM_AudiocodecMsAdpcm(fourcc,info);
+                                        break;
 				case WAV_PCM:
     					printf("\n Audio codec:  WAV\n");
 #ifdef ADM_BIG_ENDIAN				
@@ -56,10 +64,16 @@ ADM_Audiocodec *out;
 					out= (ADM_Audiocodec *)new ADM_AudiocodecWav(fourcc);
 #endif					
                   			break;
-                                case WAV_AMRNB:
-                                        printf("\n AMR narrow band codec\n");
-                                        out=(ADM_Audiocodec *)new ADM_AudiocodecAMR(fourcc,info);
-                                        break;
+#ifdef USE_AMR_NB
+				case WAV_AMRNB:
+					if (amrnb->isAvailable())
+					{
+						printf("\n AMR narrow band codec\n");
+						out=(ADM_Audiocodec *)new ADM_AudiocodecAMR(fourcc,info);
+					}
+
+					break;
+#endif
 				case WAV_8BITS:
 					printf("\n 8 BIts pseudo codec\n");
     					out= (ADM_Audiocodec *)new ADM_Audiocodec8Bits(fourcc);
@@ -84,10 +98,14 @@ ADM_Audiocodec *out;
                   break;
 #endif
 #ifdef USE_LIBDCA
-                                case WAV_DTS:
-                                    printf("\n Audio codec:  DTS\n");
-                                    out= (ADM_Audiocodec *) new ADM_AudiocodecDCA(fourcc, info);
-                                    break;
+                case WAV_DTS:
+					if (dca->isAvailable())
+					{
+						printf("\n Audio codec:  DTS\n");
+						out= (ADM_Audiocodec *) new ADM_AudiocodecDCA(fourcc, info);						
+					}
+
+					break;
 #endif
 #ifdef USE_MP3
 				case WAV_MP3:
@@ -105,11 +123,17 @@ ADM_Audiocodec *out;
 						break;
 #endif		
 #ifdef USE_FAAD
+                                case WAV_AAC_HE:
+						printf("\n MP4 audio (HE)\n");
+						out= (ADM_Audiocodec *) new ADM_faad(fourcc,1,info,
+								extra,extraData);
+						break;
+
 				case WAV_AAC:
 				case WAV_MP4:
                                 case 0x706D:  // Weird fourcc/id code used by mencoder
 						printf("\n MP4 audio \n");
-						out= (ADM_Audiocodec *) new ADM_faad(fourcc,info,
+						out= (ADM_Audiocodec *) new ADM_faad(fourcc,0,info,
 								extra,extraData);
 						break;
 #endif
@@ -117,6 +141,11 @@ ADM_Audiocodec *out;
 						printf("\n ULAW codec\n");
 						out=(ADM_Audiocodec *) new ADM_AudiocodecUlaw(fourcc,info);
 						break;
+            case WAV_AMV_ADPCM:
+                printf("\n Audio codec:  ffAMV\n");
+                out= (ADM_Audiocodec *) new ADM_AudiocodecWMA(fourcc,info,extra,extraData);
+                break;
+
             case WAV_WMA:
                 printf("\n Audio codec:  ffWMA\n");
                 out= (ADM_Audiocodec *) new ADM_AudiocodecWMA(fourcc,info,extra,extraData);
@@ -125,15 +154,23 @@ ADM_Audiocodec *out;
                 printf("\n Audio codec:  ffQDM2\n");
                 out= (ADM_Audiocodec *) new ADM_AudiocodecWMA(fourcc,info,extra,extraData);
                 break;
-            default:
-             			printf("\n Unknown codec : %lu",fourcc);
-             			out= (ADM_Audiocodec *) new ADM_AudiocodecUnknown(fourcc);
         	}
 
-	ch_route.input_type[0] = CH_FRONT_LEFT;
-	ch_route.input_type[1] = CH_FRONT_RIGHT;
+	if (out == NULL)
+	{
+		printf("\n Unknown codec : %lu",fourcc);
+		out = (ADM_Audiocodec *) new ADM_AudiocodecUnknown(fourcc);
+	}
+        if(info->channels==1)
+        {
+            ch_route.input_type[0] = CH_MONO;
+        }else
+        {
+	   ch_route.input_type[0] = CH_FRONT_LEFT;
+	   ch_route.input_type[1] = CH_FRONT_RIGHT;
+        }
 
-         return out;
+	return out;
 }
 
 ADM_Audiocodec::ADM_Audiocodec( uint32_t fourcc ) {
