@@ -26,7 +26,7 @@
 #include "ADM_audiocodec/ADM_audiocodec.h"
 #include "ADM_audiofilter/audiofilter_channel_route.h"
 
-#include "ADM_toolkit/ADM_cpuCap.h"
+#include "ADM_osSupport/ADM_cpuCap.h"
 #include "prefs.h"
 
 #ifdef USE_AC3
@@ -108,7 +108,7 @@ uint8_t ADM_AudiocodecAC3::run(uint8_t *inptr, uint32_t nbIn, float *outptr,   u
         if(length==0)
         {
             printf("[a52] No startcode found\n");
-            ADM_assert(0); 
+            break;
         }
         if(length>nbIn)
         {
