@@ -25,7 +25,7 @@
 #include <ADM_assert.h>
 #include <math.h>
 
-#include "ADM_library/default.h"
+#include "ADM_utilities/default.h"
 
 #include "audioprocess.hxx"
 //
