@@ -34,8 +34,10 @@ void audioFilter_configureFilters( void );
 
 void audioCodecConfigure( void );
 void audioCodecSelect( void );
-
-typedef enum AUDIOENCODER
+void audioFilter_MP3DisableReservoir(int onoff);
+uint32_t audioFilter_getOuputCodec(void);
+uint32_t audioFilter_getOuputFrequency(uint32_t inputFrequency);
+typedef enum 
 {
 	AUDIOENC_NONE,
 	AUDIOENC_MP3,
@@ -52,14 +54,14 @@ typedef enum AUDIOENCODER
 	AUDIOENC_DUMMY
 }AUDIOENCODER;
 
-typedef enum RESAMPLING
+typedef enum 
 {
 	RESAMPLING_NONE=0,
-	RESAMPLING_CUSTOM=2,
+	RESAMPLING_CUSTOM=1,
 	RESAMPLING_LAST
 }RESAMPLING;
 
-typedef enum FILMCONV
+typedef enum 
 {
 	FILMCONV_NONE=0,
 	FILMCONV_FILM2PAL=1,
@@ -100,7 +102,7 @@ void audioFilterResample(uint32_t onoff);
 uint8_t audioFilterDelay(int32_t delay);
 uint8_t audioFilterFilm2Pal(uint8_t onoff);
 uint8_t audioFilterPal2Film(uint8_t onoff);
-
+uint8_t audioFilterDrc(uint8_t onoff);
 void audioFilter_SetBitrate( int i);
 /* -- Get filter -- */
 uint32_t audioGetBitrate(void);
@@ -109,6 +111,7 @@ int32_t audioGetNormalizeValue(void);
 uint32_t audioGetResample(void);
 uint32_t audioGetDelay(void);
 FILMCONV audioGetFpsConv(void);
+uint32_t audioGetDrc(void);
 RESAMPLING  audioGetResampling(void);
 /*-----*/
 uint8_t                 A_changeAudioStream(AVDMGenericAudioStream *newaudio,AudioSource so,char *name);
