@@ -251,6 +251,11 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
 
 
 #ifdef USE_FFMPEG
+  if (fourCC::check (fcc, (uint8_t *) "Y800"))
+    {
+
+      return (decoders *) (new decoderFFY800 (w, h));
+    }
   if (fourCC::check (fcc, (uint8_t *) "H263"))
     {
 
@@ -413,7 +418,7 @@ if (fourCC::check (fcc, (uint8_t *) "MJPG")
     {
       uint32_t lavcodec_mpeg = 0;
       printf ("\n using Mpeg1/2 codec (libmpeg2)\n");
-      if (!prefs->get (FEATURE_USE_LAVCODEC_MPEG, &lavcodec_mpeg))
+      if (!prefs->get (FEATURE_USE_LAVCODEC_MPEG2, &lavcodec_mpeg))
 	{
 	  lavcodec_mpeg = 0;
 	}
