@@ -38,9 +38,9 @@ to generic audio stream
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_editor/ADM_edAudio.hxx"
 
-#include "ADM_toolkit/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_AUDIO_EDITOR
-#include "ADM_toolkit/ADM_debug.h"
+#include "ADM_osSupport/ADM_debug.h"
 
 
 extern ADM_Composer *video_body;
