@@ -48,8 +48,7 @@
 // Ugly but sooo usefull
 extern uint32_t frameStart,frameEnd;
 static uint32_t edFrameStart,edFrameEnd;
-uint8_t loadVideoCodecConf( char *name);
-uint8_t saveVideoCodecConf( char *name);
+uint8_t loadVideoCodecConf( const char *name);
 const char *getCurrentContainerAsString(void);
 
 uint8_t ADM_Composer::getMarkers(uint32_t *start, uint32_t *end)
@@ -70,7 +69,7 @@ uint8_t ADM_Composer::getMarkers(uint32_t *start, uint32_t *end)
 // Save the config, including name, segment etc...
 //______________________________________________
 
-uint8_t ADM_Composer::saveWorbench (char *name)
+uint8_t ADM_Composer::saveWorbench (const char *name)
 {
         GUI_Error_HIG(QT_TR_NOOP("Unsupported"), NULL);
         return 0;
@@ -78,7 +77,7 @@ uint8_t ADM_Composer::saveWorbench (char *name)
 /*______________________________________________
         Save the project as a script
 ______________________________________________*/
-uint8_t ADM_Composer::saveAsScript (char *name, char *outputname)
+uint8_t ADM_Composer::saveAsScript (const char *name, const char *outputname)
 {
 const char *truefalse[]={"false","true"};
 printf("\n **Saving script project **\n");
@@ -296,7 +295,7 @@ char *pth;
 // Save the config, including name, segment etc...
 //______________________________________________
 
-uint8_t ADM_Composer::loadWorbench (char *name)
+uint8_t ADM_Composer::loadWorbench (const char *name)
 {
   GUI_Error_HIG(QT_TR_NOOP("Old format project file"),QT_TR_NOOP( "No more supported."));
  return 0;
