@@ -33,9 +33,9 @@
 #include "ADM_filter/video_filters.h"
 #include "avi_vars.h"
 
-#include "ADM_toolkit/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_EDITOR
-#include "ADM_toolkit/ADM_debug.h"
+#include "ADM_osSupport/ADM_debug.h"
 
 #include "ADM_pp.h"
 
@@ -219,6 +219,7 @@ uint8_t  ADM_Composer::getUncompressedFrame (uint32_t frame, ADMImage * out,
 		
 	}
 	// No b frame...
+        
       	 if(!decodeCache(relframe,ref, result))			
 			{
 				printf("Editor: Cannot read ip frame %lu\n",relframe);
@@ -362,17 +363,18 @@ uint8_t  ADM_Composer::getUncompressedFrame (uint32_t frame, ADMImage * out,
 
 uint8_t		ADM_Composer::decodeCache(uint32_t frame,uint32_t seg, ADMImage *image)
 {
-uint32_t len;
-uint32_t flags,sumit;
+
+uint32_t sumit;
 float	 sum;
 EditorCache *cache=_videos[seg]._videoCache;	
 ADMImage *tmpImage=NULL;
 uint8_t refOnly=0;
 uint32_t left,ww;
-
-	 if (!_videos[seg]._aviheader->getFrameNoAlloc (frame,
-						     compBuffer,
-						     &len, &flags))
+ADMCompressedImage img;
+        aprintf("decodeCache : Frame %u\n",frame);
+        img.data=compBuffer;
+        img.cleanup(frame);
+	 if (!_videos[seg]._aviheader->getFrameNoAlloc (frame,&img))
 	{
 	  printf ("\nEditor: last decoding failed.%ld)\n",   frame );
 	  return 0;
@@ -384,7 +386,7 @@ uint32_t left,ww;
 
         refOnly=_videos[seg].decoder->dontcopy(); // can we skip one memcpy ?
 
-        if(!len & refOnly & !frame)      // Size is null = no image and we only got a pointer
+        if(!img.dataLength & refOnly & !frame)      // Size is null = no image and we only got a pointer
                                 // copy the previous one
         {                
                 // First image
@@ -431,7 +433,7 @@ uint32_t left,ww;
        }
 	tmpImage->_colorspace=ADM_COLOR_YV12;
 	// Do pp, and use imageBuffer as intermediate buffer
-	if (!_videos[seg].decoder->uncompress (compBuffer, tmpImage, len, &flags))
+	if (!_videos[seg].decoder->uncompress (&img, tmpImage))
 	    {
 	      printf ("\nEditor: Last Decoding2 failed for frame %lu\n",frame);
 	       // Try to dupe previous frame
