@@ -44,10 +44,8 @@
 #include "ADM_filter/video_filters.h"
 #include "ADM_filter/vidVCD.h"
 #include "prefs.h"
-#include "ADM_dialog/DIA_resizeWiz.h"
+#include "ADM_userInterfaces/ADM_commonUI/DIA_resizeWiz.h"
 //___________________________________________
-extern FILTER_ENTRY allfilters[MAX_FILTER];
-extern uint32_t nb_video_filter;
 extern FILTER videofilters[MAX_FILTER];
 extern uint32_t nb_active_filter;
 extern ADM_Composer *video_body;
@@ -72,10 +70,16 @@ static targetFmt VCD={352, 352, 288, 240};
 static targetFmt SVCD={480, 720, 576, 480};
 static targetFmt DVD={720, 720, 576, 480};
 static targetFmt DVDHD1={352, 720, 576, 480};
-static targetFmt PSP={320, 320, 240, 240};
-targetFmt *allFormats[5]={&VCD,&SVCD,&DVD,&DVDHD1,&PSP};
+static targetFmt PSP={480, 480, 272, 272};
+static targetFmt PSPH264={720, 720, 480, 480};
+static targetFmt IPOD={320, 320, 240, 240};
+static targetFmt IPOD640={640, 640, 480, 480};
+
+/* Dont forget to update DIA_resizeWiz if you change something here */
+
+targetFmt *allFormats[]={&VCD,&SVCD,&DVD,&DVDHD1,&PSP,&PSPH264,&IPOD,&IPOD640};
 extern AVDMGenericVideoStream *createResampleFps(AVDMGenericVideoStream *in,uint32_t targetfps1000);
-#define ARME(x) format=RESWIZ_##x;
+#define ARME(x) format=RESWIZ_##x
 
 uint8_t setVCD (void)
 {
@@ -83,6 +87,25 @@ uint8_t setVCD (void)
   ARME (VCD);
   return computeResize();
 }
+
+/**
+    \fn     setIPOD (void)
+    \brief  Setup  video size & fps to be compatible with IPOD
+*/
+uint8_t setIPOD (void)
+{
+  int8_t r=0;
+ADV_Info *info;
+uint32_t fps1000;
+
+    ARME (IPOD);
+    return computeResize();
+}
+
+/**
+    \fn     setPSP (void)
+    \brief  Setup  video size & fps to be compatible with PSP
+*/
 uint8_t setPSP (void)
 {
 uint8_t r=0;
@@ -90,24 +113,22 @@ ADV_Info *info;
 uint32_t fps1000;
 
     ARME (PSP);
-    r= computeResize();
-    if(!r) return r;
-
-    // Now change framerate to 29.96
-    info=getLastVideoFilter()->getInfo();
-    fps1000=info->fps1000;
-    if(identMovieType(fps1000) != FRAME_NTSC)
-    {
-      CONFcouple *couple;
-      
-      videofilters[nb_active_filter].filter = createResampleFps (getLastVideoFilter (), 29970);
-      videofilters[nb_active_filter].tag = VF_RESAMPLE_FPS;
-      videofilters[nb_active_filter].filter->getCoupledConf (&couple);
-      videofilters[nb_active_filter].conf = couple;;
-      nb_active_filter++;
-    }
-    return r;
+    return computeResize();
 }
+/**
+    \fn     setPSPFullRes (void)
+    \brief  Setup  video size & fps to be compatible with PSP FULL SCREEN
+*/
+uint8_t setPSPFullRes (void)
+{
+uint8_t r=0;
+ADV_Info *info;
+uint32_t fps1000;
+
+    ARME (PSP_FULLRES);
+    return computeResize();
+}
+
 uint8_t setSVCD (void)
 {
 
