@@ -105,11 +105,16 @@ typedef enum
                 VF_SWISSARMYKNIFE,
                 VF_THRESHOLD,
                 VF_PARTICLELIST,
+                VF_FRAMENUM,
                 VF_DUMMY,
                 VF_COUNT,
                 MAX_FILTER = VF_COUNT - 1,
                 VF_EXTERNAL_START=0xF0000000
           }VF_FILTERS;
+#define ADM_CONF_STRING_SIZE 256
+#define ADM_FILTER_DECLARE_CONF(fmt,...) {static char confString[ADM_CONF_STRING_SIZE];\
+                                    snprintf(confString,ADM_CONF_STRING_SIZE-1,fmt,## __VA_ARGS__);\
+                                    return confString;} 
 
 typedef AVDMGenericVideoStream *(ADM_createT) (AVDMGenericVideoStream *in, CONFcouple *);
 typedef AVDMGenericVideoStream *(ADM_create_from_scriptT) (AVDMGenericVideoStream *in, int n,Arg *args);
@@ -122,13 +127,13 @@ typedef AVDMGenericVideoStream *(ADM_create_from_scriptT) (AVDMGenericVideoStrea
         void              (*destroy)( AVDMGenericVideoStream *old); /* Maybe needed ...*/
         VF_FILTERS        tag;
         uint8_t           viewable;
-        char              *filtername;
-        char              *description;
+        const char              *filtername;
+        const char              *description;
         ADM_create_from_scriptT *create_from_script;
 
        FILTER_ENTRY (const char * name, ADM_createT * create, VF_FILTERS tag,
-                     uint8_t viewable, char * filtername,
-                     char * description = 0,
+                     uint8_t viewable, const char * filtername,
+                     const char * description = 0,
                      ADM_create_from_scriptT * create_from_script = 0)
            : name (name),
              create (create),
@@ -179,15 +184,15 @@ const char * filterGetNameFromTag(VF_FILTERS tag);
   void	filterSetPostProc( void );
   
 #ifdef USE_LIBXML2
-void filterSaveXml(char *name);
-void filterSaveXml(char *name,uint8_t silent);
-void filterLoadXml(char *name);
-int  filterLoadXml(char *name,uint8_t silent);
+void filterSaveXml(const char *name);
+void filterSaveXml(const char *name,uint8_t silent);
+void filterLoadXml(const char *name);
+int  filterLoadXml(const char *name,uint8_t silent);
 #endif
- void filterSave(char *name);
- void filterLoad(char *name);
- int filterLoad(char *name,uint8_t silent);
- void filterSave(char *name,uint8_t silent);
+ void filterSave(const char *name);
+ void filterLoad(const char *name);
+ int filterLoad(const char *name,uint8_t silent);
+ void filterSave(const char *name,uint8_t silent);
 CONFcouple *filterBuildCouple(FILTER_PARAM *param,uint32_t n,Arg *args);
 void filterSaveScriptJS(FILE *f);
 
@@ -197,12 +202,12 @@ void registerFilter(const char *name,VF_FILTERS tag,uint8_t viewable,
                     
 void registerFilterEx(const char *name,VF_FILTERS tag,uint8_t viewable,
                 ADM_createT  *create,
-		char *filtername,
+		const char *filtername,
                 ADM_create_from_scriptT *create_from_script,
-                char *description);
+                const char *description);
                 
 void 		filterListAll( void );
-VF_FILTERS 	filterGetTagFromName(char *inname);
+VF_FILTERS 	filterGetTagFromName(const char *inname);
 uint8_t 	filterAddScript(VF_FILTERS tags,uint32_t n,Arg *args);
 //AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,uint8_t *conf, AVDMGenericVideoStream *in) ;
 
