@@ -30,7 +30,7 @@
 #include "ADM_audio/aviaudio.hxx"
 
 #include "fourcc.h"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 
 #include "ADM_toolkit/toolkit.hxx"
@@ -178,7 +178,7 @@ uint8_t dmxHeader::getFrameSize(uint32_t frame,uint32_t *size) {
 
 */
 #define MAX_LINE 4096
-uint8_t                 dmxHeader::open(char *name)
+uint8_t                 dmxHeader::open(const char *name)
 {
                 FILE *file;
         
