@@ -36,7 +36,7 @@
 
 //#define TEST_V2V
 
-#include "ADM_library/default.h"
+#include "default.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_assert.h"
 
@@ -46,7 +46,7 @@
 #include "ADM_toolkit/filesel.h"
 #include "ADM_mpegdemuxer/dmx_demuxer.h"
 #include "ADM_mpegdemuxer/dmx_demuxerPS.h"
-#include "ADM_dialog/DIA_working.h"
+#include "ADM_userInterfaces/ADM_commonUI/DIA_working.h"
 #define ADM_VOBSUB_NO_PADDING
 static int vobsub_parse_ifo(const char *const name, 
                      uint32_t *palette, 
@@ -59,7 +59,7 @@ static uint8_t  *padder;
 
 #define PADDER_SIZE 0x800
 
-#define MAX_LINE        2000
+#define MAX_LINE        5000
 #define MAX_BUFFER      (1*1024)
 #define MAX_LANGUAGE    10
 
@@ -163,13 +163,13 @@ uint8_t     OneTrack::dump(uint32_t number,FILE *fdIdx, FILE *fdSub,uint32_t *ou
     fprintf(fdIdx,"# alt: English\n");
     fprintf(fdIdx,"# Vob/Cell ID: 1, 1 (PTS: 0)\n");
     (*out)++;
-    for(int i=1;i<nbLines;i++) // We shift PTS & position by 1 to workaround the display bug
+    for(int i=0;i<nbLines;i++) // We shift PTS & position by 1 to workaround the display bug
     {   
         if(lines[i].pts!=ADM_NO_PTS)
         {     
             timestamp=(uint32_t)floor(lines[i].pts/90.);
             ms2time(timestamp,&hh,&mm,&ss,&ms);
-            position=lines[i-1].start;
+            position=lines[i].start;
             //printf("Stream :%d position :%x offset:%x total:%x\n",i,position,original,original+position);
             position+=original;          
             fprintf(fdIdx,"timestamp: %02d:%02d:%02d:%03d, filepos: %08x\n",hh,mm,ss,ms,position); 
@@ -190,6 +190,16 @@ uint32_t padding;
         currentPTS=pts;
         runCode=twofirst-usableSize;
         addLine(pts,index);
+#if 0
+        {
+        uint16_t hh,mm,ss,ms;
+        uint32_t timestamp;
+
+              timestamp=pts/90;
+              ms2time(timestamp,&hh,&mm,&ss,&ms);
+              printf("Line : %03u  at %02d:%02d:%02d \n",nbLines,hh,mm,ss);
+        }
+#endif
         addData(data,size);
         if(runCode<0) runCode=0;
         return 1; 
@@ -241,7 +251,7 @@ uint8_t ADM_vob2vobsub(char *nameVob, char *nameVobSub, char *nameIfo)
    memset(palette,0,sizeof(uint32_t)*16);
    if(!vobsub_parse_ifo(nameIfo,palette,&width,&height,language))
    {
-     GUI_Error_HIG(_("Ifo error"),_("Error reading ifo file, aborting."));   
+     GUI_Error_HIG(QT_TR_NOOP("Ifo error"),QT_TR_NOOP("Error reading ifo file, aborting."));   
         return 0;
    } 
    printf("Ifo: %d x %d\n",width,height);                 
@@ -249,7 +259,7 @@ uint8_t ADM_vob2vobsub(char *nameVob, char *nameVobSub, char *nameIfo)
    indexFile=fopen(nameVobSub,"wt");
    if(!indexFile)
    {
-     GUI_Error_HIG(_("Cannot write .idx"),NULL);              
+     GUI_Error_HIG(QT_TR_NOOP("Cannot write .idx"),NULL);              
         return 0;
     }
    subname=ADM_strdup(nameVobSub);
@@ -262,7 +272,7 @@ uint8_t ADM_vob2vobsub(char *nameVob, char *nameVobSub, char *nameIfo)
     if(!indexSub)
     {
         fclose(indexFile);
-        GUI_Error_HIG(_("Cannot write .sub"),NULL);
+        GUI_Error_HIG(QT_TR_NOOP("Cannot write .sub"),NULL);
         return 0;
     }
    for(int i=0;i<MAX_LANGUAGE;i++)
@@ -274,7 +284,7 @@ uint8_t ADM_vob2vobsub(char *nameVob, char *nameVobSub, char *nameIfo)
    demuxer=new  dmx_demuxerPS(1,&track,1);
    if(!demuxer->open(nameVob))
    {
-     GUI_Error_HIG(_("Problem opening the mpeg files"),NULL);
+     GUI_Error_HIG(QT_TR_NOOP("Problem opening the mpeg files"),NULL);
         delete demuxer;
         fclose(indexFile);
         fclose(indexSub);
@@ -287,10 +297,12 @@ uint8_t ADM_vob2vobsub(char *nameVob, char *nameVobSub, char *nameIfo)
     int display=0;
     
    dumpHeader(indexFile,0,width,height,palette);
-   working=new DIA_working("Generating VobSub file");
+   working=new DIA_working(QT_TR_NOOP("Generating VobSub file"));
    
    //*** Main Loop ***
    uint32_t startPts=0,lastPts=0;
+   uint16_t hh,mm,ss,ms;
+   uint32_t timestamp;
    while(1)
    {
        if(!demuxer->forceRefill(&stream)) goto _abt;
@@ -316,13 +328,12 @@ uint8_t ADM_vob2vobsub(char *nameVob, char *nameVobSub, char *nameIfo)
                                 {
                                         if(lastPts-pts>MIN_WRAP_VALUE)
                                         {
-                                                uint16_t hh,mm,ss,ms;
-                                                uint32_t timestamp;
+                                                
                                                 printf("Wrapping at %u ",lastPts);
                                                 startPts+=lastPts;
                                                 timestamp=startPts/90;
                                                 ms2time(timestamp,&hh,&mm,&ss,&ms);
-                                                printf("%02d:%02d:%02d ",hh,mm,ss);
+                                                printf("%02d:%02d:%02d \n",hh,mm,ss);
                                         }
                                 }
                         }
@@ -330,6 +341,14 @@ uint8_t ADM_vob2vobsub(char *nameVob, char *nameVobSub, char *nameIfo)
                         lastPts=pts;
                         pts+=startPts;
             }
+#if 0
+            if(pts!=ADM_NO_PTS)
+            {
+              timestamp=pts/90;
+              ms2time(timestamp,&hh,&mm,&ss,&ms);
+              printf("%02d:%02d:%02d \n",hh,mm,ss);
+            }
+#endif
             blockSize=demuxer->read16i();
             allIndex[stream-0x20].run(blockSize,data,packetLen,usedLen, pts)  ;
        }
