@@ -359,6 +359,17 @@ uint32_t extraLen=0;
 		extraLen=4;
 		}
 		break;
+#if 1		
+	case WAV_DTS:
+	case WAV_AC3: // Vista compatibility
+		 		  extra=(uint8_t *)wmaheader;
+		 		  extra[0]=0;
+		 		  extra[1]=0;
+				  extraLen=2;
+				  header->dwScale = 1;  
+				  wav.blockalign=1;	
+			break;
+#endif			
 	case WAV_MP3:							
 		  // then update VBR fields
 		  mp3vbr.cbsize = R16(12);
@@ -410,13 +421,18 @@ uint32_t extraLen=0;
 			header->dwSampleSize 	= wav.blockalign;
 			header->dwInitialFrames =1;				
 			header->dwSuggestedBufferSize=10*wav.blockalign;				
-			
 			extra=(uint8_t *)&wmaheader;
 			extraLen=12;
 			break;
+    case WAV_PCM:
+    case WAV_LPCM:
+            header->dwScale=header->dwSampleSize=wav.blockalign=2*wav.channels; // Realign
+            header->dwLength/=header->dwScale;
+            break;
           case WAV_8BITS_UNSIGNED:
                         wav.encoding=WAV_PCM;
-			header->dwScale 	= 1;
+			header->dwScale=header->dwSampleSize=wav.blockalign=wav.channels;
+			header->dwLength/=header->dwScale;
                         wav.bitspersample=8;
                         break;
                         
@@ -1022,7 +1038,7 @@ bool aviWrite::odml_index_frame(int stream_nbr, uint32_t data_size, bool keyFram
 	}
 	return true;
 }
-void aviWrite::odml_write_sindex(int stream_nbr, char* stream_fcc)
+void aviWrite::odml_write_sindex(int stream_nbr, const char* stream_fcc)
 {
         
 	// Warning: This changes the file position
@@ -1075,7 +1091,7 @@ void aviWrite::odml_write_sindex(int stream_nbr, char* stream_fcc)
                 
 	}	
 }
-bool aviWrite::odml_write_index(int stream_nbr, char* stream_fcc, char* index_fcc){	// write index
+bool aviWrite::odml_write_index(int stream_nbr, const char* stream_fcc, const char* index_fcc){	// write index
 	// Warning: This changes the file position
 	if(doODML==NORMAL){
 		aprintf ("\n writing %lu interleaved ODML indexes for %lu frames in stream %s", odml_indexes[stream_nbr].index_count+1, vframe, stream_fcc);
