@@ -121,15 +121,15 @@ uint8_t r=0;
 uint32_t skipping=1;
 pthread_t     audioThread;
 audioQueueMT context;
-PacketQueue   *pq;//("MP4 audioQ",50,2*1024*1024);
+PacketQueue   *pq = NULL;//("MP4 audioQ",50,2*1024*1024);
 uint32_t    totalAudioSize=0;
 uint32_t sent=0;
 const char *containerTitle;
            switch(type)
            {
-             case ADM_PSP:muxerType=MUXER_PSP;containerTitle="PSP";break;
-             case ADM_MP4:muxerType=MUXER_MP4;containerTitle="MP4";break;
-             case ADM_MATROSKA:muxerType=MUXER_MATROSKA;containerTitle="MKV";break;
+             case ADM_PSP:muxerType=MUXER_PSP;containerTitle=QT_TR_NOOP("PSP");break;
+             case ADM_MP4:muxerType=MUXER_MP4;containerTitle=QT_TR_NOOP("MP4");break;
+             case ADM_MATROSKA:muxerType=MUXER_MATROSKA;containerTitle=QT_TR_NOOP("MKV");break;
              default:
                 ADM_assert(0);
            }
@@ -161,9 +161,9 @@ const char *containerTitle;
                
                   encoding_gui->setContainer(containerTitle);
                
-                encoding_gui->setAudioCodec("None");
+                encoding_gui->setAudioCodec(QT_TR_NOOP("None"));
                 if(!videoProcessMode())
-                        encoding_gui->setCodec("Copy");
+                        encoding_gui->setCodec(QT_TR_NOOP("Copy"));
                 else
                         encoding_gui->setCodec(_encode->getDisplayName());
                 TwoPassLogFile=new char[strlen(name)+6];
@@ -185,7 +185,7 @@ const char *containerTitle;
                                 goto stopit;
                 }else
                 {
-                        encoding_gui->setPhasis ("Encoding");
+                        encoding_gui->setPhasis (QT_TR_NOOP("Encoding"));
                 }
                 
                 info.width=_incoming->getInfo()->width;
@@ -257,15 +257,31 @@ preFilling:
           if(audio)
           {
                 audioinfo=audio->getInfo();
+
+				if (muxerType == MUXER_MP4)
+				{
+					switch (audioinfo->encoding)
+					{
+						case WAV_MP2:
+						case WAV_MP3:
+						case WAV_AAC:
+						case WAV_AAC_HE:
+							break;
+						default:
+							if (!GUI_YesNo(QT_TR_NOOP("Invalid audio stream detected"), QT_TR_NOOP("The audio stream may be invalid for this container.\n\nContinue anyway?")))
+								goto stopit;
+					}
+				}
+
                 audio->extraData(&extraDataSize,&extraData);
                 if(audioProcessMode())
                         encoding_gui->setAudioCodec(getStrFromAudioCodec(audio->getInfo()->encoding));
                 else
-                         encoding_gui->setAudioCodec("Copy");
+                         encoding_gui->setAudioCodec(QT_TR_NOOP("Copy"));
 
            }else
            {
-                encoding_gui->setAudioCodec("None");
+                encoding_gui->setAudioCodec(QT_TR_NOOP("None"));
            }
 // ____________Setup Muxer _____________________
            muxer= new lavMuxer;
@@ -282,7 +298,7 @@ preFilling:
           encoding_gui->setContainer(containerTitle);
          
           if(!videoProcessMode())
-                encoding_gui->setCodec("Copy");
+                encoding_gui->setCodec(QT_TR_NOOP("Copy"));
           else
                 encoding_gui->setCodec(_encode->getDisplayName());
            //
@@ -360,7 +376,7 @@ preFilling:
 stopit:
     printf("2nd pass, sent %u frames\n",sent);
     // Flush slave Q
-    if(audio)
+    if(pq)
     {
         context.audioAbort=1;
         pq->Abort();
@@ -407,7 +423,7 @@ uint8_t prepareDualPass(uint32_t bufferSize,uint8_t *buffer,char *TwoPassLogFile
         if(!reuse)
         {
         
-                encoding_gui->setPhasis ("1st Pass");
+                encoding_gui->setPhasis (QT_TR_NOOP("1st Pass"));
                 aprintf("**Pass 1:%lu\n",total);
                 _encode->startPass1 ();
                 bitstream.data=buffer;
@@ -464,7 +480,7 @@ preFilling2:
                 return 0;
         }
         printf("First pass : send %u frames\n",sent);
-        encoding_gui->setPhasis ("2nd Pass");
+        encoding_gui->setPhasis (QT_TR_NOOP("2nd Pass"));
         return 1;
 }
 void end (void)
