@@ -3,12 +3,12 @@
 #include <stdlib.h>
 #include <string.h>
 #include <pthread.h>
+#include "default.h"
+#include "ADM_toolkit/toolkit.hxx"
 #include "ADM_JSGlobal.h"
 #include "ADM_JSAvidemux.h"
 #include "ADM_JSDirectorySearch.h"
 #include "ADM_assert.h"
-#include "ADM_library/default.h"
-#include "ADM_toolkit/toolkit.hxx"
 
 extern uint8_t JS_AvidemuxFunction(JSContext *cx,JSObject *global);
 extern void A_Resync(void);
@@ -27,8 +27,16 @@ FILE *fd = fopen(report->filename,"rb");
 		fclose(fd);
 	}
 	if( strncmp(buf,"//AD",4) ){
+            if (report->filename || report->lineno)
 		GUI_Error_HIG("Spidermonkey ECMAScript Error",
-		              "Not an ECMAScript file. Try open it with 'File' -> 'Open...'");
+		              "%s: line %d:\nMsg: %s\n"
+                              "Not an ECMAScript file. Try open it with 'File' -> 'Open...'",
+                              report->filename,
+                              report->lineno,
+                              message);
+            else
+		GUI_Error_HIG("Spidermonkey ECMAScript Error",
+                              "Not an ECMAScript file. Try open it with 'File' -> 'Open...'");
 	}else{
 		GUI_Error_HIG("Spidermonkey ECMAScript Error", 
 			"%s: line %d:\nMsg: %s\n",
@@ -36,6 +44,11 @@ FILE *fd = fopen(report->filename,"rb");
 			report->lineno,
 			message);
 	}
+        fprintf(stderr, "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@  Spidermonkey ECMAScript Error\n");
+        if (report->filename || report->lineno)
+            fprintf(stderr, "\t%s: line %d:\n\tMsg: %s\n",
+                   report->filename, report->lineno, message);
+
         if(quiet)
                 GUI_Quiet();
 
@@ -83,7 +96,9 @@ bool SpidermonkeyInit()
 
 void SpidermonkeyDestroy()
 {// begin SpidermonkeyDestroy
-	JS_SetContextThread(g_pCx);
+#ifdef ADM_JS_THREADSAFE
+	JS_SetContextThread(g_pCx);	
+#endif
 	JS_DestroyContext(g_pCx);
 	JS_DestroyRuntime(g_pRt);
 }// end SpidermonkeyDestroy
@@ -98,8 +113,10 @@ void *StartThreadSpidermonkey(void *pData)
         http://archive.gingerall.cz/archives/public/sablot2004/msg00117.html
         */
         // Notify the Spidermonkey that we'll be processing in a thread
+#ifdef ADM_JS_THREADSAFE
         JS_SetContextThread(g_pCx);
         JS_BeginRequest(g_pCx);
+#endif
         bool ret = false;
         const char *pScriptFile = static_cast<const char *>(pData);
         ret = parseECMAScript(pScriptFile);
@@ -110,9 +127,12 @@ void *StartThreadSpidermonkey(void *pData)
                 actual_workbench_file = ADM_strdup(pScriptFile);
         }
         // Notify Spidermonkey that our thread processing has finished
+#ifdef ADM_JS_THREADSAFE
         JS_EndRequest(g_pCx);
         JS_ClearContextThread(g_pCx);
+#endif
         pthread_mutex_unlock(&g_pSpiderMonkeyMutex);
+
         return NULL;
 }// end StartThreadSpidermonkey
 
@@ -137,6 +157,8 @@ bool parseECMAScript(const char *name)
 		JS_DestroyScript(g_pCx,pJSScript);
 		printf("Done.\n");
 	}// end execute external file
+        // Run garbage collector now, it is safe
+        JS_GC(g_pCx);
 	A_Resync();
 	return g_bJSSuccess;
 }// end parseECMAScript
