@@ -21,7 +21,9 @@ at amistry@am-productions.biz
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <dirent.h>
+#include <string.h>
 #endif
+#include <cstring>
 #include "StdFile.h"
 
 // create a non file bit for unix
