@@ -16,8 +16,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "ADM_library/default.h"
-#include "ADM_cpuCap.h"
+#include "ADM_utilities/default.h"
+#include "ADM_osSupport/ADM_cpuCap.h"
 
 #include "ADM_assert.h"
 
