@@ -57,7 +57,7 @@ static int cb_mod2(GtkObject * object, gpointer user_data);
 static uint32_t videoDuration;
 static uint32_t track1, track2;
 
-uint32_t numberOfVideoFrames;
+static uint32_t numberOfVideoFrames;
 
 static uint32_t videoSize,videoBitrate;
 
@@ -69,6 +69,10 @@ void DIA_Calculator(uint32_t *sizeInMeg, uint32_t *avgBitrate )
 	if(!avifileinfo) return ;
 	
 	dialog=create_Calculator();
+	gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+										GTK_RESPONSE_CANCEL,
+										GTK_RESPONSE_APPLY,
+										-1);
 	gtk_register_dialog(dialog);
         gtk_signal_connect(GTK_OBJECT(WID(optionmenu1)), "changed",
                       GTK_SIGNAL_FUNC(cb_mod),   (void *) 0);
