@@ -67,6 +67,10 @@ uint32_t w,h;
         h=in->getInfo()->height;
 
         dialog=create_dialog1();
+		gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+											GTK_RESPONSE_OK,
+											GTK_RESPONSE_CANCEL,
+											-1);
         gtk_register_dialog(dialog);
         gtk_widget_show(dialog);	
         
