@@ -264,6 +264,11 @@ uint8_t DIA_particle (AVDMGenericVideoStream *in,
     uint32_t height = in->getInfo()->height;
 
     dialog = create_particle_dialog();
+
+	gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+								GTK_RESPONSE_OK,
+								GTK_RESPONSE_CANCEL,
+								-1);
     gtk_register_dialog (dialog);
     gtk_window_set_title (GTK_WINDOW (dialog),
                           QT_TR_NOOP("Particle Analysis Configuration"));
