@@ -65,6 +65,11 @@ int code;
       ADM_assert(incoming->extraSettingsLen==sizeof(localParam));
       memcpy(&localParam,incoming->extraSettings,sizeof(localParam));
       dialog=create_dialog1();
+
+	gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+										GTK_RESPONSE_OK,
+										GTK_RESPONSE_CANCEL,
+										-1);
       gtk_register_dialog(dialog);
 
 #define HIST_SET(x) gtk_option_menu_set_history(GTK_OPTION_MENU(WID(optionmenuType)), x)
@@ -162,11 +167,8 @@ _erLoad:
 					incoming->mode = COMPRESS_CQ;		      			
 					value = (uint32_t) gtk_spin_button_get_value_as_int(
 								GTK_SPIN_BUTTON(WID(spinbuttonQuant)));
-		      			if (value >= 2 && value <= 32)
-						{
-			    			incoming->qz = value;
-		      				}
-		      			break;
+					incoming->qz = value;
+					break;
 
 				case 2:
 		     				incoming->mode = COMPRESS_2PASS;		       				
@@ -435,6 +437,11 @@ int code;
 int col, row;
 
       dialog=create_dialog3();
+
+	gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+										GTK_RESPONSE_OK,
+										GTK_RESPONSE_CANCEL,
+										-1);
       gtk_register_dialog(dialog);
       //
       for(int i=0;i<64;i++)
@@ -785,8 +792,8 @@ create_dialog1 (void)
   gtk_tooltips_set_tip (tooltips, entryEntry, QT_TR_NOOP("Target video bitrate"), NULL);
   gtk_entry_set_width_chars (GTK_ENTRY (entryEntry), 10);
 
-  spinbuttonQuant_adj = gtk_adjustment_new (4, 1, 31, 0.1, 10, 10);
-  spinbuttonQuant = gtk_spin_button_new (GTK_ADJUSTMENT (spinbuttonQuant_adj), 1, 1);
+  spinbuttonQuant_adj = gtk_adjustment_new (4, 1, 31, 1, 10, 10);
+  spinbuttonQuant = gtk_spin_button_new (GTK_ADJUSTMENT (spinbuttonQuant_adj), 1, 0);
   gtk_widget_show (spinbuttonQuant);
   gtk_box_pack_start (GTK_BOX (vbox22), spinbuttonQuant, FALSE, FALSE, 0);
   gtk_tooltips_set_tip (tooltips, spinbuttonQuant, QT_TR_NOOP("Constant quantizer - each frame will get the same compression"), NULL);
@@ -1037,7 +1044,7 @@ create_dialog1 (void)
   gtk_container_add (GTK_CONTAINER (frame_par1), hbox_par1);
   gtk_container_set_border_width (GTK_CONTAINER (hbox_par1), 5);
 
-  checkbutton_par_asinput = gtk_check_button_new_with_mnemonic (QT_TR_NOOP("As input"));
+  checkbutton_par_asinput = gtk_check_button_new_with_mnemonic (QT_TR_NOOP("As Input"));
   gtk_widget_show (checkbutton_par_asinput);
   gtk_box_pack_start (GTK_BOX (hbox_par1), checkbutton_par_asinput, FALSE, FALSE, 10);
   gtk_tooltips_set_tip (tooltips, checkbutton_par_asinput, QT_TR_NOOP("Get PAR from input video file"), NULL);
