@@ -44,8 +44,9 @@
 #include "../ADM_toolkit_gtk/gtkmarkscale.h"
 #include "../ADM_toolkit_gtk/jogshuttle.h"
 #include "../ADM_toolkit_gtk/ADM_jogshuttle.h"
+#include "gtkgui.h"
 
-uint8_t UI_getPhysicalScreenSize(uint32_t *w,uint32_t *h);
+extern uint8_t UI_getPhysicalScreenSize(void* window, uint32_t *w,uint32_t *h);
 
 
 #define WOD(x) lookup_widget (guiRootWindow,#x)
@@ -53,7 +54,7 @@ uint8_t UI_getPhysicalScreenSize(uint32_t *w,uint32_t *h);
 void frame2time(uint32_t frame, uint32_t fps, uint16_t * hh, uint16_t * mm,
 	   uint16_t * ss, uint16_t * ms);
 
-static GtkWidget *guiRootWindow=NULL;
+GtkWidget *guiRootWindow=NULL;
 static GtkWidget *guiDrawingArea=NULL;
 static GtkWidget *guiSlider=NULL;
 
@@ -79,8 +80,8 @@ static void volumeChange( void );
 static char     *customNames[ADM_MAC_CUSTOM_SCRIPT];
 static uint32_t ADM_nbCustom=0;
 // Needed for DND
-extern void A_openAvi (char *name);
-extern void A_appendAvi (char *name);
+// extern int A_openAvi (char *name);
+extern int A_appendAvi (const char *name);
 
 
 static void on_audio_change(void);
@@ -106,10 +107,6 @@ enum
         TARGET_ROOTWIN,
         TARGET_URL
 };
-enum 
-{
-   TARGET_URI_LIST
-};
  
 static GtkTargetEntry target_table[] = 
 {
@@ -128,7 +125,7 @@ extern GtkWidget	*create_mainWindow (void);
 extern void guiCallback(GtkMenuItem * menuitem, gpointer user_data);
 extern void HandleAction(Action act);
 extern gboolean UI_on_key_press(GtkWidget *widget, GdkEventKey* event, gpointer user_data);
-extern void fileReadWrite(SELFILE_CB cb, int rw, char *name);
+extern void fileReadWrite(SELFILE_CB *cb, int rw, const char *name);
 
 // To build vcodec
 extern uint32_t encoderGetNbEncoder(void);
@@ -202,6 +199,104 @@ buttonCallBack_S buttonCallback[]=
   
 };
 
+#ifdef ENABLE_WINDOW_SIZING_HACK
+
+// This is a hack to empirically determine the largest window for which there
+// is room on the screen, allowing for panels and such.  There doesn't seem to
+// be any way to query GTK for this information, so we create a window,
+// maximize it and make it visible, wait for the real configure event that
+// comes after it is actually maximized, and record the size that it had in
+// that event.  That size is what we take to be the largest window that will
+// fit.  We use that information later to calculate how much (and whether or
+// not) to scale down the preview video in flyDialogs, via
+// UI_calcZoomToFitScreen() in GUI_gtkRender.cpp.
+
+int maxWindowWidth = -1;
+int maxWindowHeight = -1;
+
+gboolean tmpwin_configured (GtkWidget * widget, GdkEventConfigure * event,
+                            gpointer user_data)
+{
+    printf ("tmpwin_configured: now %dx%d @ +%d+%d\n",
+            event->width, event->height, event->x, event->y);
+
+    // it always seems to get two events, one at a 200x200 dimension and then
+    // the one at the maximized dimensions.  An alternate approach here would
+    // be to ignore the first configure event and use the 2nd.  Yet another
+    // way would be to do the maximize call here on the first event...
+
+    if (event->width > 200)
+    {
+        maxWindowWidth = event->width;
+        maxWindowHeight = event->height;
+        gtk_widget_destroy (widget);
+    }
+
+    return TRUE;
+}
+
+void do_tmpwin_hack (void)
+{
+    GtkWidget * tmpwin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+    g_signal_connect (GTK_OBJECT (tmpwin), "configure-event",
+                      GTK_SIGNAL_FUNC (tmpwin_configured),
+                      gpointer (tmpwin));
+    gtk_window_maximize (GTK_WINDOW(tmpwin));
+    gtk_widget_show (tmpwin);
+}
+
+#endif
+
+// This is part of a hack to allow the user to attach the Play and Stop
+// actions to buttons.  The problem is that once we launch the Play action,
+// HandleAction() doesn't return to its caller until avidemux stops playing,
+// so if HandleAction() is called directly from the event handler, there is no
+// way for the Stop button to be seen until something else has already stopped
+// it.  However, if we have the event handler just set up a timer, which
+// launches the play action, it's only the timer that is locked up, and since
+// we only use the timer for the Play action (and not any of the other
+// buttons), then everything (including the Stop button) works just fine.
+// A GTK expert might know of a better way to solve this problem, but I'm not
+// convinced that one exists in current GTK (2.10 on my FC7 system, but we
+// need to support older ones, too).
+
+static gboolean on_PlayButtonHackTimer (gpointer data)
+{
+    gdk_threads_enter();
+    HandleAction (ACT_PlayAvi);
+    gdk_threads_leave();
+    return FALSE;
+}
+
+void jogButton (void *, unsigned short /* raw_button */, Action gui_action)
+{
+    // hack alert: see comment for on_PlayButtonHackTimer(), above
+    if (gui_action == ACT_PlayAvi)
+        g_timeout_add (10, on_PlayButtonHackTimer, NULL);
+    else if (gui_action != ACT_INVALID)
+        HandleAction (gui_action);
+}
+
+void jogDial (void *, signed short offset) // offset usually -1 or +1
+{
+    if (offset < 0)
+        GUI_PrevFrame (uint32_t (-offset));
+    else
+        GUI_NextFrame (uint32_t (offset));
+}
+
+GtkWidget * lookup_jog_shuttle_widget (void)
+{
+    return lookup_widget(guiRootWindow,"jogg");
+}
+
+void jogRing (void *, gfloat angle) // angle is -1.0 to 0 to +1.0
+{
+    GtkWidget * jsw = lookup_jog_shuttle_widget();
+    if (jsw)
+        jog_shuttle_set_value (jsw, angle);
+}
+
 ///
 ///	Create main window and bind to it
 ///
@@ -214,6 +309,10 @@ uint32_t w,h;
 		
 		if(!guiRootWindow) return 0;
 
+#ifdef ENABLE_WINDOW_SIZING_HACK
+                do_tmpwin_hack();
+#endif
+
 		gtk_register_dialog(guiRootWindow);
 					
 		// and seek global sub entity
@@ -226,12 +325,13 @@ uint32_t w,h;
 		GUI_initCursor(  );
     
                 
-                UI_getPhysicalScreenSize(&w,&h); //gtk_widget_get_parent_window (guiRootWindow));
+                UI_getPhysicalScreenSize(guiRootWindow, &w, &h);
                 printf("The screen seems to be %u x %u px\n",w,h);
  
                 GUI_gtk_grow_off(1);
 #ifdef USE_JOG
                 physical_jog_shuttle = &(PhysicalJogShuttle::getInstance());
+                physical_jog_shuttle->registerCBs (NULL, jogButton, jogDial, jogRing);
 #endif 
 	return ret;
 }
@@ -243,6 +343,7 @@ void destroyGUI(void)
 	for(int i=0;i<ADM_nbCustom;i++)
 		delete(customNames[i]);
 #ifdef USE_JOG
+        physical_jog_shuttle->deregisterCBs (NULL);
         delete physical_jog_shuttle;
 #endif
 }
@@ -588,22 +689,28 @@ int32_t UI_readJog(void)
         
 }
 
-GtkWidget * lookup_jog_shuttle_widget (void)
-{
-    return lookup_widget(guiRootWindow,"jogg");
-}
-
 void UI_setTitle(const char *name)
 {
-        char title[1024];
+	char *title;
+	const char* defaultTitle = "Avidemux";
 
-        strncpy(title,name,200);
-        title[200] = 0;
-        strncat(title," - Avidemux", 11);
+	if (name && strlen(name) > 0)
+	{
+		title = new char[strlen(defaultTitle) + strlen(name) + 3 + 1];
 
+		strcpy(title, name);
+		strcat(title, " - ");
+		strcat(title, defaultTitle);
+	}
+	else
+	{
+		title = new char[strlen(defaultTitle) + 1];
 
-        gtk_window_set_title (GTK_WINDOW (guiRootWindow), title);
+		strcpy(title, defaultTitle);
+	}
 
+	gtk_window_set_title(GTK_WINDOW (guiRootWindow), title);
+	delete [] title;
 }
 void UI_setFrameType( uint32_t frametype,uint32_t qp)
 {
@@ -711,6 +818,8 @@ int UI_grabFocus( void)
 	RM(buttonPrevKFrame, GDK_KP_2);
 
 	RM(delete1, GDK_Delete);
+	RM(set_marker_a1,GDK_bracketleft);
+	RM(set_marker_b1,GDK_bracketright);
 
 	RMCTRL(paste1,GDK_V);
 	RMCTRL(copy1,GDK_C);
@@ -734,13 +843,16 @@ int UI_loseFocus( void)
 	ADD_ACT(previous_frame1, GDK_KP_4);
 	ADD_ACT(next_intra_frame1, GDK_KP_8);
 	ADD_ACT(previous_intra_frame1, GDK_KP_2);
-	ADD_ACT(delete1, GDK_Delete);
 
 	ADD(buttonNextFrame, GDK_KP_6);
 	ADD(buttonPrevFrame, GDK_KP_4);
 	ADD(buttonNextKFrame, GDK_KP_8);
 	ADD(buttonPrevKFrame, GDK_KP_2);
-	
+
+	ADD_ACT(delete1, GDK_Delete);
+	ADD_ACT(set_marker_a1,GDK_bracketleft);
+	ADD_ACT(set_marker_b1,GDK_bracketright);
+
 	ADDCTRL(paste1,GDK_V);
 	ADDCTRL(copy1,GDK_C);
 	ADDCTRL(cut1,GDK_X);
@@ -841,13 +953,14 @@ void UI_JumpDone(void )
 
 
 }
-uint32_t UI_readCurFrame( void )
+int UI_readCurFrame( void )
 {
-int i;
-	i=gtk_read_entry(guiCurFrame);
-	if(i<0) i=0;
-	return  (uint32_t)i;
-	 
+	int i = gtk_read_entry(guiCurFrame);
+
+	if(i < 0)
+		i = 0;
+
+	return i;
 }
 
 int UI_readCurTime(uint16_t &hh, uint16_t &mm, uint16_t &ss, uint16_t &ms)
@@ -1020,21 +1133,25 @@ uint8_t UI_SetCurrentFormat( ADM_OUT_FORMAT fmt )
     \fn DNDmerge
     \brief Extract the actual filename from the DNDstring file://abcd and store it into where
 */
-static void DNDmerge(char **where, char *start,char *end)
+static void DNDmerge(char **where, char *start, char *end)
 {
-  int len=end-start;
-  ADM_assert(len>7); // file:// = 7 bytes
-  len-=7;
-  *where=(char *)ADM_alloc(end-start+1);  // 7 more but who cares ?
-  memcpy(*where,start+7,len);
-  
-  // chomp it
-  char *tail=(*where)+len;
-  do
-  { 
-      *tail=0;
-      tail--;
-  }while(*tail==0xA || *tail==0xd);
+	char urlFile[end - start + 1];
+	char *tail = urlFile + (end - start);
+
+	memcpy(urlFile, start, end - start);
+
+	do
+	{
+		*tail = 0;
+		tail--;
+	} while (*tail == '\r' || *tail == '\n');
+
+	gchar *filename = g_filename_from_uri(urlFile, NULL, NULL);
+
+	*where = new char[strlen(filename) + 1];
+	strcpy(*where, filename);
+
+	g_free(filename);
 }
 // DND CYB
 #define MAX_DND_FILES 20
@@ -1050,7 +1167,7 @@ void DNDDataReceived( GtkWidget *widget, GdkDragContext *dc,
    char *names[MAX_DND_FILES];
    
     memset(names,0,sizeof(char *)*MAX_DND_FILES);
-    if (info != TARGET_URI_LIST)
+    if (info != TARGET_STRING && info != TARGET_URL)
     {
       gtk_drag_finish(dc,TRUE,FALSE,t);
       return;
@@ -1084,15 +1201,13 @@ void DNDDataReceived( GtkWidget *widget, GdkDragContext *dc,
     for(int i=0;i<current-1;i++)
     {
       printf("DND : %d %s\n",i,names[i]);
-      char *filename=names[i];
-      if (avifileinfo) 
-              {
-                    fileReadWrite(A_appendAvi, 0, (char*)filename);
-               }
-               else
-               {
-                    fileReadWrite(A_openAvi, 0, (char*)filename);
-               }
+      const char *filename = names[i];
+
+	  if (avifileinfo)
+		  fileReadWrite(reinterpret_cast <void (*)(const char *)> (A_appendAvi), 0, filename);
+	  else
+		  fileReadWrite(reinterpret_cast <void (*)(const char *)> (A_openAvi), 0, filename);
+
       ADM_dealloc(names[i]); 
     }
     gtk_drag_finish(dc,TRUE,FALSE,t);
@@ -1124,6 +1239,8 @@ uint8_t UI_getTimeShift(int *onoff,int *value)
 }
 uint8_t UI_setTimeShift(int onoff,int value)
 {
+	if (!value)
+		onoff = 0;
 
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (lookup_widget(guiRootWindow,"CheckButtonTimeshift")),onoff);
         gtk_spin_button_set_value(GTK_SPIN_BUTTON(lookup_widget(guiRootWindow,"spinbuttonTimeShift")),value) ;
@@ -1174,6 +1291,8 @@ uint8_t UI_arrow_disabled(void)
 
 gboolean UI_SliderPressed(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
 {
+	gtk_widget_grab_focus(lookup_widget(guiRootWindow, "menuBar"));
+
 	if(event->state&GDK_SHIFT_MASK) SliderIsShifted=TRUE;
 	return FALSE;
 
@@ -1187,7 +1306,6 @@ extern int global_argc;
 extern char **global_argv;
 typedef gboolean GCALL       (void *);
 extern int automation(void );
-extern uint8_t UI_getPhysicalScreenSize(uint32_t *w,uint32_t *h);
 extern void initTranslator(void);
 
 int UI_Init(int argc, char **argv)
