@@ -38,7 +38,7 @@
 #include "ADM_toolkit_gtk/toolkit_gtk_include.h"
 #include "ADM_toolkit_gtk/toolkit_gtk.h"
 
-extern char * actual_workbench_file;
+extern void fileReadWrite(SELFILE_CB *cb, int rw, const char *name);
 
 static void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw, char **name=NULL);
 char            *PathCanonize(const char *tmpname);
@@ -73,6 +73,12 @@ DIR *dir=NULL;
                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                                       NULL);
+
+	gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+										GTK_RESPONSE_ACCEPT,
+										GTK_RESPONSE_CANCEL,
+										-1);
+
 	gtk_window_set_title (GTK_WINDOW (dialog),title);
         initFileSelector();
         setFilter(dialog);
@@ -145,6 +151,12 @@ DIR *dir=NULL;
                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                                       NULL);
+
+	gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+										GTK_RESPONSE_ACCEPT,
+										GTK_RESPONSE_CANCEL,
+										-1);
+
 	gtk_window_set_title (GTK_WINDOW (dialog),title);
         initFileSelector();
         setFilter(dialog);
@@ -239,6 +251,12 @@ DIR *dir=NULL;
                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                                       NULL);
+
+	gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+										GTK_RESPONSE_ACCEPT,
+										GTK_RESPONSE_CANCEL,
+										-1);
+
         gtk_window_set_title (GTK_WINDOW (dialog),title);
         gtk_register_dialog(dialog);
         /* Set default dir if provided ..*/
@@ -307,98 +325,6 @@ void GUI_FileSelWrite(const char *label, char * * name)
     GUI_FileSel(label, NULL, 1,name);
 }
 
-// CYB 2005.02.23: DND
-void fileReadWrite(SELFILE_CB *cb, int rw, char *name)
-{
-
-	if(name)
-	{
-		if(cb)
-		{
-			FILE *fd;
-			fd=fopen(name,"rb");
-			if(rw==0) // read
-			{
-				// try to open it..
-				if(!fd)
-				{
-                                  GUI_Error_HIG(QT_TR_NOOP("File error"), QT_TR_NOOP("Cannot open \"%s\"."), name);
-					return;
-				}
-			}
-			else // write
-			{
-				if(fd){
-				  struct stat buf;
-				  int fdino;
-					fclose(fd);
-
-					char msg[300];
-
-					snprintf(msg, 300, QT_TR_NOOP("%s already exists.\n\nDo you want to replace it?"), GetFileName(name));
-
-                                        if(!GUI_Question(msg))
-						return;
-	                                /*
-	                                ** JSC Fri Feb 10 00:07:30 CET 2006
-	                                ** compare existing output file inode against each current open files inode
-	                                ** i'm ignoring st_dev, so we may get false positives
-	                                ** i'm testing until fd=1024, should be MAXFD computed by configure
-	                                ** keep in mind:
-	                                ** you can overwrite .idx files, they are loaded into memory and closed soon
-	                                ** you cannot overwrite segment data files, all files are kept open and
-	                                ** are detected here
-	                                */
-#ifndef ADM_WIN32
-					if( stat(name,&buf) == -1 ){
-						fprintf(stderr,"stat(%s) failed\n",name);
-						return;
-					}
-#endif
-					fdino = buf.st_ino;
-					for(int i=0;i<1024;i++){
-						if( fstat(i,&buf) != -1 ){
-							if( buf.st_ino == fdino ){
-							  char str[512];
-								snprintf(str,512,"File \"%s\" exists and is opened by Avidemux",name);
-								GUI_Error_HIG(str,
-                                                                    QT_TR_NOOP("It is possible that you are trying to overwrite an input file!"));
-								return;
-							}
-						}
-					}
-					/*
-	                                ** compare output file against actual EMCAscript file
-					** need to stat() to avoid symlink (/home/x.js) vs. real file (/export/home/x.js) case
-	                                */
-					if( actual_workbench_file ){
-						if( stat(actual_workbench_file,&buf) != -1 ){
-							if( buf.st_ino == fdino ){
-							  char str[512];
-								snprintf(str,512,"File \"%s\" exists and is the actual ECMAscript file",name);
-                                                                GUI_Error_HIG(str,QT_TR_NOOP("It is possible that you are trying to overwrite an input file!"));
-								return;
-							}
-						}
-					}
-				}
-
-				// check we have right access to it
-				fd=fopen(name,"wb");
-				if(!fd)
-				{
-                                  GUI_Error_HIG(QT_TR_NOOP("Cannot write the file"),QT_TR_NOOP( "No write access to \"%s\"."), name);
-					return;
-				}
-			}
-			fclose(fd);
-			cb(name);
-		} // no callback -> return value
-	}
-}
-// CYB 2005.02.23: DND
-
-
 void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
 {				/* Create the selector */
 
@@ -414,7 +340,7 @@ void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
 
         if(rw)
         {
-                        dialog=dialog = gtk_file_chooser_dialog_new ("Save",
+                        dialog = gtk_file_chooser_dialog_new ("Save",
                                       NULL,
                                       GTK_FILE_CHOOSER_ACTION_SAVE,
                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -424,13 +350,18 @@ void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
         }
         else
         {
-          dialog=dialog = gtk_file_chooser_dialog_new ("Open File",
+          dialog = gtk_file_chooser_dialog_new ("Open File",
                                       NULL,
                                       GTK_FILE_CHOOSER_ACTION_OPEN,
                                       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                                       NULL);
         }
+
+		gtk_dialog_set_alternative_button_order(GTK_DIALOG(dialog),
+											GTK_RESPONSE_ACCEPT,
+											GTK_RESPONSE_CANCEL,
+											-1);
 		gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
         /**********/
         initFileSelector();
