@@ -20,16 +20,16 @@ uint8_t FileSel_SelectDir(const char *title,char *target,uint32_t max, const cha
 { 
   return 0;
 }
-void GUI_FileSelRead(const char *label,SELFILE_CB cb) 
+void GUI_FileSelRead(const char *label,SELFILE_CB *cb) 
 {}
-void GUI_FileSelWrite(const char *label,SELFILE_CB cb) 
+void GUI_FileSelWrite(const char *label,SELFILE_CB *cb) 
 {}
 void GUI_FileSelRead(const char *label, char * * name)
 {}
 void GUI_FileSelWrite(const char *label, char * * name)
 {}
 
-uint8_t UI_getPhysicalScreenSize(uint32_t *w,uint32_t *h)
+uint8_t UI_getPhysicalScreenSize(void *window, uint32_t *w,uint32_t *h)
 {
   *w=*h=10000; 
-}
\ No newline at end of file
+}
