@@ -17,6 +17,8 @@
 #include <stdlib.h>
 #include <math.h>
 
+#include <QtCore/QFileInfo>
+#include <QtCore/QUrl>
 #include <QtCore/QVariant>
 #include <QtGui/QAction>
 #include <QtGui/QApplication>
@@ -37,11 +39,12 @@
 #include "ADM_editor/ADM_outputfmt.h"
 #include "ADM_toolkit/filesel.h"
 #include "prefs.h"
+#include "avi_vars.h"
 
 extern int global_argc;
 extern char **global_argv;
 
-extern uint8_t UI_getPhysicalScreenSize(uint32_t *w,uint32_t *h);
+extern uint8_t UI_getPhysicalScreenSize(void* window, uint32_t *w,uint32_t *h);
 extern int automation(void );
 extern void HandleAction(Action a);
 extern uint32_t encoderGetNbEncoder (void);
@@ -53,6 +56,9 @@ extern void UI_QT4VideoWidget(QFrame *frame);
 extern void loadTranslator(void);
 extern void initTranslator(void);
 extern void destroyTranslator(void);
+extern int A_openAvi(const char *name);
+extern int A_appendAvi(const char *name);
+extern void fileReadWrite(SELFILE_CB *cb, int rw, const char *name);
 
 int SliderIsShifted=0;
 static void setupMenus(void);
@@ -224,11 +230,8 @@ protected:
 	void clearCustomMenu(void);
 	bool eventFilter(QObject* watched, QEvent* event);
 	void mousePressEvent(QMouseEvent* event);
-
-private slots:
-
-private:
-
+	void dragEnterEvent(QDragEnterEvent *event);
+	void dropEvent(QDropEvent *event);
 };
 
 
@@ -330,6 +333,8 @@ MainWindow::MainWindow() : QMainWindow()
 	ui.lineEdit_2->installEventFilter(this);
 
 	this->setFocus(Qt::OtherFocusReason);
+
+	setAcceptDrops(true);
 }
 /**
 \fn     custom
@@ -470,6 +475,40 @@ void MainWindow::mousePressEvent(QMouseEvent* event)
 	this->setFocus(Qt::OtherFocusReason);
 }
 
+void MainWindow::dragEnterEvent(QDragEnterEvent *event)
+{
+	if (event->mimeData()->hasFormat("text/uri-list"))
+		event->acceptProposedAction();
+}
+
+void MainWindow::dropEvent(QDropEvent *event)
+{
+	QList<QUrl> urlList;
+	QString fileName;
+	QFileInfo info;
+
+	if (event->mimeData()->hasUrls())
+	{
+		urlList = event->mimeData()->urls();
+
+		for (int fileIndex = 0; fileIndex < urlList.size(); fileIndex++)
+		{
+			fileName = urlList[fileIndex].toLocalFile();
+			info.setFile(fileName);
+
+			if (info.isFile())
+			{
+				if (avifileinfo)
+					fileReadWrite(reinterpret_cast <void (*)(const char *)> (A_appendAvi), 0, fileName.toUtf8().data());
+				else
+					fileReadWrite(reinterpret_cast <void (*)(const char *)> (A_openAvi), 0, fileName.toUtf8().data());
+			}
+		}
+	}
+
+	event->acceptProposedAction();
+}
+
 void MainWindow::previousIntraFrame(void)
 {
 	if (ui.spinBox_TimeValue->hasFocus())
@@ -527,7 +566,7 @@ void MainWindow::buildCustomMenu(void)
 
 		for(int i=0; i < ADM_nbCustom; i++)
 		{
-			customActions[i] = new QAction(GetFileName(customNames[i]), NULL);
+			customActions[i] = new QAction(QString::fromUtf8(GetFileName(customNames[i])), NULL);
 			ui.menuCustom->addAction(customActions[i]);
 			connect(customActions[i], SIGNAL(triggered()), this, SLOT(custom()));
 		}
@@ -622,16 +661,16 @@ int UI_RunApp(void)
 
 	loadTranslator();
 
-	uint32_t w, h;
-
-	UI_getPhysicalScreenSize(&w,&h);
-	printf("The screen seems to be %u x %u px\n",w,h);
-
 	MainWindow *mw = new MainWindow();
 	mw->show();
 
 	QuiMainWindows = (QWidget*)mw;
 
+	uint32_t w, h;
+
+	UI_getPhysicalScreenSize(QuiMainWindows, &w,&h);
+	printf("The screen seems to be %u x %u px\n",w,h);
+
 	UI_QT4VideoWidget(mw->ui.frame_video);  // Add the widget that will handle video display
 	UI_updateRecentMenu();
 	setupMenus();
@@ -749,11 +788,11 @@ void UI_setScale( double val )
 	_upd_in_progres--;
 }
 
-uint32_t UI_readCurFrame(void)
+int UI_readCurFrame(void)
 {
 	bool ok;
 	
-	return WIDGET(lineEdit)->text().toUInt(&ok);
+	return WIDGET(lineEdit)->text().toInt(&ok);
 }
 
 int UI_readCurTime(uint16_t &hh, uint16_t &mm, uint16_t &ss, uint16_t &ms)
@@ -795,13 +834,28 @@ void UI_purge( void )
 */
 void UI_setTitle(const char *name)
 {
-    char title[300];
+	char *title;
+	const char* defaultTitle = "Avidemux";
 
-    strncpy(title,name,200);
-    strncat(title," - Avidemux", 11);
+	if (name && strlen(name) > 0)
+	{
+		title = new char[strlen(defaultTitle) + strlen(name) + 3 + 1];
+
+		strcpy(title, name);
+		strcat(title, " - ");
+		strcat(title, defaultTitle);
+	}
+	else
+	{
+		title = new char[strlen(defaultTitle) + 1];
+
+		strcpy(title, defaultTitle);
+	}
 
 	QuiMainWindows->setWindowTitle(QString::fromUtf8(title));
+	delete [] title;
 }
+
 /**
     \fn     UI_setFrameType( uint32_t frametype,uint32_t qp)
     \brief  Display frametype (I/P/B) and associated quantizer
@@ -992,7 +1046,7 @@ uint8_t UI_getTimeShift(int *onoff,int *value)
 
 uint8_t UI_setTimeShift(int onoff,int value)
 {
-	if(onoff)
+	if (onoff && value)
 		WIDGET(checkBox_TimeShift)->setCheckState(Qt::Checked);
 	else
 		WIDGET(checkBox_TimeShift)->setCheckState(Qt::Unchecked);
