@@ -34,9 +34,9 @@ uint8_t DIA_mjpegCodecSetting(COMPRES_PARAMS *param)
         ADM_assert(sizeof(MJPEGConfig)==param->extraSettingsLen);
         uint8_t ret=0;
         diaElemUInteger  qual(&(config->qual),QT_TR_NOOP("_Quality:"),1,100);
-        diaElemToggle    swap(&(config->swapped),QT_TR_NOOP("_Swap U&V:"));
+        diaElemToggle    swap(&(config->swapped),QT_TR_NOOP("_Swap U&V"));
         diaElem *elems[2]={&qual,&swap};
-        if( diaFactoryRun(QT_TR_NOOP("Mjpeg Configuration"),2,elems))
+        if( diaFactoryRun(QT_TR_NOOP("MJPEG Configuration"),2,elems))
         {
             ret=1;
         }
