@@ -41,7 +41,13 @@
 
 extern AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *couple, AVDMGenericVideoStream *in);
 
+
+static FILTER_PARAM partialParam={VARIABLE_PARAMS+3,{"_start","_end","_tag"}};
+
+
+SCRIPT_CREATE(partial_script,ADMVideoPartial,partialParam);
 BUILD_CREATE(partial_create,ADMVideoPartial);
+
 //___________________________________________________
 char 						*ADMVideoPartial::printConf(void)
 {
@@ -138,7 +144,7 @@ uint8_t ADMVideoPartial::getFrameNumberNoAlloc(uint32_t frame,
 				uint32_t *flags)
 {
 		ADM_assert(_son);
-		
+		if(frame>= _info.nb_frames) return 0;
 		if((frame+_info.orgFrame>=_param->_start) && (frame+_info.orgFrame)<=_param->_end) // 
 		{
 				return _son->getFrameNumberNoAlloc(frame,len,data,flags);
