@@ -221,11 +221,8 @@ uint8_t Decimate::configure(AVDMGenericVideoStream *in)
 
 char *Decimate::printConf( void )
 {
- 	static char buf[50];
-
-	ADM_assert(_param);
- 	sprintf((char *)buf," Decomb Decimate cycle:%d",_param->cycle);
-        return buf;
+ 	ADM_FILTER_DECLARE_CONF(" Decomb Decimate cycle:%d",_param->cycle);
+        
 }
 
 
@@ -912,6 +909,7 @@ uint8_t Decimate::getFrameNumberNoAlloc(uint32_t frame, uint32_t *len,
 		//return src;
 		//memcpy(data,src,*len);
 
+                GETFRAME(useframe, src); // MEANX : not sure (jw detected a problem here)
 		data->duplicate(src);
 		vidCache->unlockAll();		
 		return 1; // return src;			
