@@ -44,8 +44,8 @@
 
 #include "ADM_assert.h"
 
-static int16_t scaletab[16];
-static uint64_t scaletab_MMX[65536];
+static int16_t scaletab[16] asm(MANGLE(scaletab));
+static uint64_t scaletab_MMX[65536] asm(MANGLE(scaletab_MMX));
 
 void initScaleTab( void )
 {
@@ -72,19 +72,20 @@ SCRIPT_CREATE(fluxsmooth_script,ADMVideoFlux,fluxParam);
 //#define ASM_FLUX
 BUILD_CREATE(fluxsmooth_create,ADMVideoFlux);
 
-static uint64_t spat_thresh ASM_CONST =0LL;
-static uint64_t temp_thresh ASM_CONST =0LL;
-static uint64_t ASM_CONST _l_counter_init,_l_indexer,_l_prev_pels,_l_next_pels;
-static long int _l_src_pitch ASM_CONST =0;
-static long int _l_dst_pitch ASM_CONST =0;
-static int _l_xmax ASM_CONST=0;
-
-static int ycnt;
-static	uint8_t * _l_currp; 
-static	 uint8_t * _l_prevp;								  								  
-static	 uint8_t * _l_nextp; 
-static	 uint8_t * _l_destp; 
+static uint64_t spat_thresh asm(MANGLE(spat_thresh)) ASM_CONST =0LL;
+static uint64_t temp_thresh asm(MANGLE(temp_thresh)) ASM_CONST =0LL;
+static uint64_t ASM_CONST _l_counter_init asm(MANGLE(_l_counter_init)),
+	_l_indexer asm(MANGLE(_l_indexer)), _l_prev_pels asm(MANGLE(_l_prev_pels)),
+	_l_next_pels asm(MANGLE(_l_next_pels));
+static long int _l_src_pitch asm(MANGLE(_l_src_pitch)) ASM_CONST =0;
+static long int _l_dst_pitch asm(MANGLE(_l_dst_pitch)) ASM_CONST =0;
+static int _l_xmax asm(MANGLE(_l_xmax)) ASM_CONST=0;
 
+static int ycnt asm(MANGLE(ycnt));
+static uint8_t * _l_currp asm(MANGLE(_l_currp));
+static uint8_t * _l_prevp asm(MANGLE(_l_prevp));
+static uint8_t * _l_nextp asm(MANGLE(_l_nextp));
+static uint8_t * _l_destp asm(MANGLE(_l_destp));
 
 static uint32_t size;
 
