@@ -22,10 +22,8 @@
 
 #include <time.h>
 #include <sys/time.h>
-#include <fcntl.h>	/* O_RDONLY */
 #include <errno.h>
-#include <glib.h>
-    
+
 #include "ADM_lavcodec.h"
 
 #include "fourcc.h"
@@ -68,10 +66,15 @@
 
 #include "ADM_userInterfaces/ADM_commonUI/DIA_factory.h"
 
+static AudioSource currentAudioSource = AudioAvi;
+static AudioSource secondAudioSource = AudioNone;
+static char *currentAudioName = NULL;
+static char *secondAudioName = NULL;
+
 void A_handleSecondTrack (int tracktype);
 int A_delete(uint32_t start, uint32_t end);
-void A_saveImg (char *name);
-void A_saveBunchJpg( char *name);
+void A_saveImg (const char *name);
+void A_saveBunchJpg( const char *name);
 void A_requantize(void);
 int A_saveJpg (char *name);
 int A_loadWave (char *name);
@@ -79,9 +82,9 @@ int A_loadAC3 (char *name);
 int A_loadMP3 (char *name);
 int A_loadNone( void );
 void A_saveAudioDecodedTest (char *name);
-void A_openBrokenAvi (char *name);
-int A_openAvi2 (char *name, uint8_t mode);
-int A_appendAvi (char *name);
+void A_openBrokenAvi (const char *name);
+int A_openAvi2 (const char *name, uint8_t mode);
+int A_appendAvi (const char *name);
 void A_externalAudioTrack( void );
 
 void HandleAction (Action action);
@@ -117,7 +120,7 @@ extern uint8_t indexMpeg (char *mpeg, char *file, uint8_t aid);
 void ADM_cutWizard (void);
 uint8_t  ADM_saveRaw (const char *name);
 char * actual_workbench_file;
-void A_saveWorkbench (char *name);
+void A_saveWorkbench (const char *name);
 void updateLoaded (void);
 extern void encoderSetLogFile (char *name);
 extern void videoCodecSelect (void);
@@ -149,7 +152,7 @@ uint8_t A_TimeShift(void);
 PARAM_MUX muxMode = MUX_REGULAR;
 int muxParam = 0;
 
-extern uint8_t UI_getPhysicalScreenSize(uint32_t *w,uint32_t *h);
+extern uint8_t UI_getPhysicalScreenSize(void* window, uint32_t *w,uint32_t *h);
 extern uint8_t GUI_jobs(void);
 extern bool parseECMAScript(const char *name);
 void A_parseECMAScript(const char *name);
@@ -158,7 +161,7 @@ uint8_t DIA_builtin(void);
 renderZoom currentZoom=ZOOM_1_1;
 uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name);
 extern const char * GUI_getCustomScript(uint32_t nb);
-extern gboolean SliderIsShifted;
+extern bool SliderIsShifted;
 
 void GUI_showCurrentFrameHex(void);
 void GUI_avsProxy(void);
@@ -175,7 +178,6 @@ extern void DIA_glyphEdit(void);
 
 void HandleAction (Action action)
 {
-  gchar *name_utf8;
   static int recursive = 0;
 
   uint32_t nf = 0;
@@ -193,7 +195,7 @@ int nw;
   }
   switch (action)
     {
-        case ACT_GLYPHEDIT: 
+        case ACT_GLYPHEDIT:
                                 DIA_glyphEdit();
                                 return;
         case ACT_AVS_PROXY:
@@ -209,7 +211,7 @@ int nw;
                                 GUI_jobs();
                                 return;
         case ACT_RECENT0:
-        case ACT_RECENT1:        
+        case ACT_RECENT1:
         case ACT_RECENT2:
         case ACT_RECENT3:
                         const char **name;
@@ -217,9 +219,8 @@ int nw;
                                 name=prefs->get_lastfiles();
                                 rank=(int)action-ACT_RECENT0;
                                 ADM_assert(name[rank]);
-				name_utf8 = g_filename_from_utf8(name[rank], -1, NULL, NULL, NULL);
-                                A_openAvi2 (name_utf8, 0);
-				g_free(name_utf8);
+                                A_openAvi2 (name[rank], 0);
+
                 return;
         case ACT_ViewMain: UI_toogleMain();return;
         case ACT_ViewSide: UI_toogleSide();return;
@@ -242,15 +243,15 @@ int nw;
    case ACT_AudioCodecChanged:
                 nw=UI_getCurrentACodec();
    		audioCodecChanged(nw);
-    		
+
 		return;
-    
+
     case ACT_RunScript:
                 GUI_FileSelRead (QT_TR_NOOP("Select ECMAScript to Run"),(SELFILE_CB *) A_parseECMAScript);
-                        
+
                         //
     		return;
-		
+
     case ACT_RecentFiles:
     	char *file;
 		if(		DIA_RecentFiles(&file))
@@ -278,17 +279,17 @@ int nw;
     	if(DIA_Preferences())
 	{
 	saveEncoderConfig ();
- 	#ifdef HAVE_AUDIO     
+ 	#ifdef HAVE_AUDIO
       		AVDM_audioSave();
- 	#endif     
-      	prefs->save ();	
-	}      
+ 	#endif
+      	prefs->save ();
+	}
 	return;
     case ACT_SavePref:
       saveEncoderConfig ();
- #ifdef HAVE_AUDIO     
+ #ifdef HAVE_AUDIO
       AVDM_audioSave();
- #endif     
+ #endif
       prefs->save ();
       return;
     case ACT_SetLogFile:
@@ -300,7 +301,7 @@ int nw;
       ADM_aviUISetMuxer();
       return;
       break;
-#ifdef HAVE_AUDIO      
+#ifdef HAVE_AUDIO
     	case ACT_SelectDevOSS:
 				   AVDM_switch (DEVICE_OSS);
 				   return;break;
@@ -313,7 +314,7 @@ int nw;
 	case ACT_SelectDevALSA:
 				   AVDM_switch (DEVICE_ALSA);
 				   return;break;
-#endif                                  
+#endif
     case ACT_Fast:
       ADM_assert(0);
       break;
@@ -323,11 +324,11 @@ int nw;
          if( saveprefsonexit )
             prefs->save ();
       }
-      cleanUp (); 
+      cleanUp ();
       exit (0);
       break;
 /*			case ACT_SelectEncoder:
-				
+
 						A_selectEncoder();
   	  			return;
 						break;*/
@@ -339,7 +340,7 @@ int nw;
       break;
 
     }
-//------------------------------------------------                                      
+//------------------------------------------------
 
   if (playing)			// only allow some action
     {
@@ -390,7 +391,7 @@ int nw;
       return;
     }
 
-//#define TEST_UNPACK    
+//#define TEST_UNPACK
   // we have an AVI loaded
   switch (action)
     {
@@ -438,16 +439,16 @@ int nw;
     			break;
     case ACT_SaveUnpackedMpeg4:
       if(GUI_Question(QT_TR_NOOP("This is to be used to undo packed VOP on MPEG-4.\nContinue ?")))
-			{ 
+			{
                           GUI_FileSelWrite (QT_TR_NOOP("Select AVI File to Write"), (SELFILE_CB *)A_SaveUnpackedVop);
-				
+
 			}
     			break;
-			
+
     case ACT_SaveOGM:
                         GUI_FileSelWrite (QT_TR_NOOP("Select OGM File to Write"), (SELFILE_CB *)ogmSave);
     			break;
-				
+
     case ACT_SaveWork:
       GUI_FileSelWrite (QT_TR_NOOP("Select Workbench to Save"), A_saveWorkbench);
 	  UI_refreshCustomMenu();
@@ -465,13 +466,11 @@ int nw;
 		UI_refreshCustomMenu();
       }
       break;
-        case ACT_JumpToFrame: 
-                // read value	
+        case ACT_JumpToFrame:
+                // read value
                 nf=UI_readCurFrame();
-                if(nf>0 && nf< avifileinfo->nb_frames)
-                {
-                        GUI_GoToFrame(nf);
-                }
+				if(nf< avifileinfo->nb_frames)
+					GUI_GoToFrame(nf);
                 UI_JumpDone();
                 break;
 	case ACT_JumpToTime:
@@ -514,7 +513,7 @@ int nw;
     case ACT_SaveWave:
       	{
           GUI_FileSelWrite (QT_TR_NOOP("Select File to Save Audio"),(SELFILE_CB *)A_audioSave);
-	
+
 	}
       break;
 
@@ -547,7 +546,7 @@ int nw;
       break;
 
     case ACT_SaveBunchJPG:
-      GUI_FileSelWrite (QT_TR_NOOP("Select JPEG Sequence to Save"), A_saveBunchJpg);      
+      GUI_FileSelWrite (QT_TR_NOOP("Select JPEG Sequence to Save"), A_saveBunchJpg);
     	break;
     case ACT_SaveImg:
       GUI_FileSelWrite (QT_TR_NOOP("Select BMP to Save"), A_saveImg);
@@ -557,7 +556,7 @@ int nw;
       GUI_FileSelWrite (QT_TR_NOOP("Select JPEG to Save"), (SELFILE_CB *)A_saveJpg);
       	//GUI_FileSelWrite ("Select Jpg to save ", A_saveJpg);
       	break;
-    
+
     case ACT_Scale:
       if (!ignore_change)
 	{
@@ -575,7 +574,7 @@ int nw;
     {
         ADM_PREVIEW_MODE oldpreview=getPreviewMode(),newpreview=(ADM_PREVIEW_MODE)UI_getCurrentPreview();
           printf("Old preview %d, New preview mode : %d\n",oldpreview,newpreview);
-          
+
           if(oldpreview==newpreview)
           {
             return;
@@ -606,10 +605,10 @@ int nw;
     case ACT_PrevBlackFrame:
       GUI_NextPrevBlackFrame(-1);
       break;
-    case ACT_AllBlackFrames:    
+    case ACT_AllBlackFrames:
       GUI_FileSelWrite (QT_TR_NOOP("Select File to Save"), (SELFILE_CB *)A_ListAllBlackFrames);
-        break;                        
-    
+        break;
+
     case ACT_PreviousFrame:
         GUI_PrevFrame();
       break;
@@ -672,7 +671,7 @@ int nw;
        A_changeAudioStream((AVDMGenericAudioStream *) NULL, AudioNone,NULL);
       break;
 
-  
+
     case ACT_MarkA:
     case ACT_MarkB:
       uint32_t swapit;
@@ -705,16 +704,10 @@ int nw;
       fn=curframe;
       if (DIA_GetIntegerValue ((int *)&fn,0,avifileinfo->nb_frames,QT_TR_NOOP("Go to Frame"),QT_TR_NOOP("_Go to frame:")))
 	{
-	  if (fn)
-	    {			// 0 probably means garbage
-	      if (fn < avifileinfo->nb_frames)
-		{
-		  curframe = fn;
-		  GUI_GoToFrame (curframe);
-		}
-	      else
-                GUI_Error_HIG (QT_TR_NOOP("Out of bounds"), NULL);
-	    }
+		if (fn < avifileinfo->nb_frames)
+			GUI_GoToFrame (curframe);
+		else
+			GUI_Error_HIG (QT_TR_NOOP("Out of bounds"), NULL);
 	}
       break;
 //----------------------test-----------------------
@@ -770,8 +763,8 @@ int nw;
 
     case ACT_Delete:
     case ACT_Cut:
-    
-     
+
+
       old=frameStart;
       if( A_delete(frameStart,frameEnd))
       {
@@ -779,11 +772,11 @@ int nw;
 	{			// we removed too much
 	  old = avifileinfo->nb_frames - 1;
 	}
-      	curframe=old;	 
-      	GUI_GoToFrame (old);      
+      	curframe=old;
+      	GUI_GoToFrame (old);
       }
-      
-      
+
+
       break;
 
     case ACT_AudioMap:
@@ -798,21 +791,47 @@ int nw;
 
     case ACT_ChangeFPS:
     	{
-      	float  fps;
-	 aviInfo info;
-	 video_body->getVideoInfo (&info);
-       	fps=info.fps1000;
-	fps/=1000.;
+         float  fps;
+         aviInfo info;
+         uint32_t useDefined=1;
+         uint32_t defaultFps[3]={25000,23976,29970};
+         uint32_t index=0;
+         video_body->getVideoInfo (&info);
+         fps=info.fps1000;
+         fps/=1000.;
 
 
-      	if (DIA_GetFloatValue (&fps, 1., 60., QT_TR_NOOP("Frame Rate"),QT_TR_NOOP("_Frames per second:")))
-	{
-	
-	  info.fps1000 = (uint32_t) (floor (fps * 1000.+0.49));
-	  video_body->updateVideoInfo (&info);
-	  // update display
-	  video_body->getVideoInfo (avifileinfo);
-	 }
+
+        diaElemToggle togUsePredefined(&useDefined,QT_TR_NOOP("Use custom value"));
+        diaElemFloat  fpsFloatValue(&fps,QT_TR_NOOP("Frame Rate"),1.,200.,QT_TR_NOOP("_Frames per second"));
+
+        diaMenuEntry menuFps[]={
+              {0,QT_TR_NOOP("PAL - 25 FPS")},
+              {1,QT_TR_NOOP("FILM- 24 FPS")},
+              {2,QT_TR_NOOP("NTSC- 30 FPS")}};
+
+         diaElemMenu      stdFps(&index,QT_TR_NOOP("Standard FrameRate:"),3,menuFps);
+
+        togUsePredefined.link(1,&fpsFloatValue);
+        togUsePredefined.link(0,&stdFps);
+
+        diaElem *elems[3]={&togUsePredefined,&fpsFloatValue,&stdFps};
+        if(diaFactoryRun(QT_TR_NOOP("Change FrameRate"),3,elems))
+        {
+          if(useDefined)
+          {
+            info.fps1000 = (uint32_t) (floor (fps * 1000.+0.49));
+          }else
+          {
+            info.fps1000=defaultFps[index];
+          }
+          video_body->updateVideoInfo (&info);
+          printf("[MainUI] New framerate :%u\n",info.fps1000);
+          // update display
+          video_body->getVideoInfo (avifileinfo);
+          rebuild_status_bar();
+
+        }
 	}
       break;
       // set decoder option (post processing ...)
@@ -849,7 +868,7 @@ int nw;
    case ACT_HEX_DUMP:
       GUI_showCurrentFrameHex();
       break;
-      
+
     default:
       printf ("\n unhandled action %d\n", action);
       ADM_assert (0);
@@ -871,21 +890,20 @@ int nw;
 //_____________________________________________________________
 
 void
-A_openBrokenAvi (char *name)
+A_openBrokenAvi (const char *name)
 {
   A_openAvi2 (name, 1);
 }
 
 int
-A_openAvi (char *name)
+A_openAvi (const char *name)
 {
   return A_openAvi2 (name, 0);
 }
 extern void GUI_PreviewEnd (void);
-int A_openAvi2 (char *name, uint8_t mode)
+int A_openAvi2 (const char *name, uint8_t mode)
 {
   uint8_t res;
-  gchar *name_utf8;
   char *longname;
   uint32_t magic[4];
   uint32_t id = 0;
@@ -910,7 +928,7 @@ int A_openAvi2 (char *name, uint8_t mode)
 
 
   GUI_close(); // Cleanup
-  
+
   DIA_StartBusy ();
   /*
   ** we may get a relative path by cmdline
@@ -933,13 +951,10 @@ int A_openAvi2 (char *name, uint8_t mode)
   if (res!=ADM_OK)			// an error occured
     {
 		delete[] longname;
-    	if(ADM_IGN==res) 
+    	if(ADM_IGN==res)
 	{
 		return 0;
 	}
-	
-	currentaudiostream = NULL;
-	avifileinfo = NULL;
 
 	if( fourCC::check(id,(uint8_t *)"//AD") ){
           GUI_Error_HIG(QT_TR_NOOP("Cannot open project using the video loader."),
@@ -968,8 +983,7 @@ int A_openAvi2 (char *name, uint8_t mode)
 	}
 
 	/* remember any video or workbench file to "recent" */
-	name_utf8 = g_filename_to_utf8(longname, -1, NULL, NULL, NULL);
-	prefs->set_lastfile(name_utf8);
+	prefs->set_lastfile(longname);
         UI_updateRecentMenu();
 	updateLoaded ();
         if(currentaudiostream)
@@ -999,30 +1013,22 @@ int A_openAvi2 (char *name, uint8_t mode)
 		}
 	UI_setTitle(longname+i);
     }
-	g_free(name_utf8);
+
 	delete[] longname;
 	return 1;
 }
 
 void  updateLoaded ()
 {
-  if (avifileinfo)
-    {
-      delete avifileinfo;
-      avifileinfo = NULL;
-    }
   avifileinfo = new aviInfo;
   if (!video_body->getVideoInfo (avifileinfo))
     {
 //      err1:
       printf ("\n get info failed...cancelling load...\n");
       delete avifileinfo;
-      avifileinfo = (aviInfo *) NULL;
-      currentaudiostream = aviaudiostream = NULL;
-
+      avifileinfo = NULL;
 
       return;
-
     }
 
   curframe = 0;
@@ -1034,7 +1040,6 @@ void  updateLoaded ()
     {
       printf ("\n *** NO AUDIO ***\n");
       wavinfo = (WAVHeader *) NULL;
-      currentaudiostream = aviaudiostream = (AVDMGenericAudioStream *) NULL;
     }
   else
     {
@@ -1051,7 +1056,7 @@ void  updateLoaded ()
 
   // Init renderer
     admPreview::setMainDimension(avifileinfo->width, avifileinfo->height);
-  curframe = 0;  
+  curframe = 0;
 
   // Draw first frame
   rebuild_status_bar();
@@ -1060,10 +1065,10 @@ void  updateLoaded ()
   UI_setMarkers (frameStart, frameEnd);
 
   getFirstVideoFilter(); // Rebuild filter if needed
-  
+
   /* Zoom out if needed */
   uint32_t phyW,phyH;
-  UI_getPhysicalScreenSize(&phyW,&phyH);
+  UI_getPhysicalScreenSize(NULL, &phyW,&phyH);
   if(phyW<avifileinfo->width || phyH<avifileinfo->height)
   {
       if(phyW<avifileinfo->width/2 || phyH<avifileinfo->height/2)
@@ -1080,12 +1085,12 @@ void  updateLoaded ()
       currentZoom=ZOOM_1_1;
       changePreviewZoom(currentZoom);
   }
-        
-  
-  
+
+
+
       admPreview::update (curframe);
       update_status_bar();
-   
+
    printf("\n** conf updated **\n");
 }
 
@@ -1093,7 +1098,7 @@ void  updateLoaded ()
 //  Append an AVI to the existing one
 //___________________________________________
 int
-A_appendAvi (char *name)
+A_appendAvi (const char *name)
 {
 
 
@@ -1180,18 +1185,18 @@ A_saveAudio (char *name)
       return;
     }
 
-  
+
   out = fopen (name, "wb");
   if (!out) return;
-  
+
   work=new DIA_working(QT_TR_NOOP("Saving audio"));
-  
+
   uint32_t timeEnd,timeStart,sample,hold,len;
   uint64_t tgt_sample,cur_sample;
   double   duration;
 
   // compute start position and duration in samples
-    
+
    timeStart=video_body->getTime (frameStart);
    timeEnd=video_body->getTime (frameEnd+1);
 
@@ -1199,12 +1204,12 @@ A_saveAudio (char *name)
    duration=timeEnd-timeStart;
    printf("Duration:%f ms\n",duration);
    if(duration<0) duration=-duration;
-  
-   duration/=1000;   
+
+   duration/=1000;
    duration*=currentaudiostream->getInfo()->frequency;
-   
-   tgt_sample=(uint64_t)floor(duration);  
-   
+
+   tgt_sample=(uint64_t)floor(duration);
+
    cur_sample=0;
    written = 0;
    hold=0;
@@ -1218,19 +1223,19 @@ A_saveAudio (char *name)
 	if(hold>ONE_STRIKE)
 	{
 		fwrite(buffer,hold,1,out);
-		hold=0;		
+		hold=0;
 	}
 	if(cur_sample>tgt_sample)
-		break;   
+		break;
       work->update(cur_sample>>10, tgt_sample>>10);
       if(!work->isAlive()) break;
     };
   if(hold)
   {
   	fwrite(buffer,hold,1,out);
-	hold=0;  
+	hold=0;
   }
-  
+
   fclose (out);
   delete work;
   delete[] buffer;
@@ -1262,7 +1267,7 @@ int A_saveJpg (char *name)
     if(!GUI_getFrameContent(&image, curframe))
     {
       GUI_Error_HIG(QT_TR_NOOP("Get Frame"),QT_TR_NOOP("Cannot get this frame to save"));
-      return 0; 
+      return 0;
     }
     return (int) image.saveAsJpg (name);
 }
@@ -1278,7 +1283,7 @@ static int b=1;
          video_body->changeAudioStream(0,b);
         b^=1;
         return 1;
- 	
+
 }
 #endif
 
@@ -1288,40 +1293,41 @@ static int b=1;
       \brief Save the selection  as a bunch of jpeg 95% qual
 
 */
-void A_saveBunchJpg(char *name)
+void A_saveBunchJpg(const char *name)
 {
   ADMImage *src=NULL;
   uint32_t curImg;
   char	 fullName[2048],*ext;
+  char *baseName;
   DIA_working *working;
   uint8_t success=0;
-  
+
         if(frameStart>frameEnd)
                 {
                   GUI_Error_HIG(QT_TR_NOOP("Mark A > B"), QT_TR_NOOP("Set your markers correctly."));
                         return;
                 }
         // Split name into base + extension
-        PathSplit(name,&name,&ext);
-        
+        PathSplit(name,&baseName,&ext);
+
         src=new ADMImage(avifileinfo->width,avifileinfo->height);
         ADM_assert(src);
 
         working=new DIA_working(QT_TR_NOOP("Saving as set of jpegs"));
         for(curImg=frameStart;curImg<=frameEnd;curImg++)
-        {	
-                working->update(curImg-frameStart,frameEnd-frameStart);	
+        {
+                working->update(curImg-frameStart,frameEnd-frameStart);
                 if (!GUI_getFrameContent (src,curImg ))
                 {
                   GUI_Error_HIG(QT_TR_NOOP("Cannot decode frame"), QT_TR_NOOP("Aborting."));
                         goto _bunch_abort;
                 }
                 if(!working->isAlive()) goto _bunch_abort;
-                sprintf(fullName,"%s%04d.jpg",name,curImg-frameStart);
+                sprintf(fullName,"%s%04d.jpg",baseName,curImg-frameStart);
                 if(!src->saveAsJpg(fullName)) goto _bunch_abort;
         }
         success=1;
-        
+
 _bunch_abort:
         if(success)
             GUI_Info_HIG(ADM_LOG_INFO,QT_TR_NOOP("Done"),QT_TR_NOOP( "Saved %d images."), curImg-frameStart);
@@ -1337,9 +1343,9 @@ _bunch_abort:
       \fn A_saveImg
       \brief Save current displayed image as a BMP file
 */
-void A_saveImg (char *name)
+void A_saveImg (const char *name)
 {
-  
+
   ADMImage image(avifileinfo->width,avifileinfo->height);
   GUI_getFrameContent(&image, curframe);
   if(image.saveAsBmp(name))
@@ -1379,16 +1385,7 @@ int A_loadNone( void )
 {
  	A_changeAudioStream ((AVDMGenericAudioStream *) NULL, AudioNone,NULL);
 }
-//_____________________________________________________________
-//
-//              Load wave
-//              
-//
-//_____________________________________________________________
-AudioSource currentAudioSource=AudioAvi;
-AudioSource secondAudioSource=AudioNone;
-char *currentAudioName=NULL;
-char *secondAudioName=NULL;
+
 //_____________________________________________________________
 //
 //              Load MP3 and identify wavfmt infos to fill avi header
@@ -1415,7 +1412,7 @@ int A_loadMP3(char *name)
 //_____________________________________________________________
 //
 //              Load wave
-//              
+//
 //
 //_____________________________________________________________
 
@@ -1451,12 +1448,18 @@ AudioSource getCurrentAudioSource(char **name)
 //________________________________________________________
 uint8_t A_changeAudioStream (AVDMGenericAudioStream * newaudio, AudioSource nwsource,char *myname)
 {
-  if (currentaudiostream)
-    {
-      currentAudioSource=AudioNone;
-      if(currentAudioName) ADM_dealloc(currentAudioName);
-      currentAudioName=NULL;
-    }
+	if (currentaudiostream)
+	{
+		if (currentaudiostream != aviaudiostream)
+			delete currentaudiostream;
+
+		if(currentAudioName)
+			ADM_dealloc(currentAudioName);
+
+		currentAudioName = NULL;
+		currentAudioSource = AudioNone;
+	}
+
   currentaudiostream = newaudio;
 
   if (currentaudiostream)
@@ -1482,9 +1485,9 @@ A_saveAudioDecodedTest (char *name)
   uint32_t written = 0;
   FILE *out;
   AVDMGenericAudioStream *saveFilter;
-  
+
   uint64_t sampleTarget,sampleCurrent;
-  
+
 #undef BITT
 #define BITT 4*1152
 #define OUTCHUNK 1024*1024
@@ -1540,7 +1543,7 @@ A_saveAudioDecodedTest (char *name)
 			ADM_dealloc(outbuffer);
 			return;
 		}
-   
+
     	DIA_working *work=new DIA_working(QT_TR_NOOP("Saving audio"));
 
 
@@ -1555,11 +1558,11 @@ A_saveAudioDecodedTest (char *name)
   duration=(tend-tstart);
   duration*=saveFilter->getInfo()->frequency;
   duration/=1000.;
-  
+
   sampleTarget=(uint64_t)floor(duration);
   sampleCurrent=0;
   gauge=0;
-  
+
   if( frameStart == frameEnd ){
      /* JSC: we will write some bytes, but nobody should expect useful data */
     GUI_Error_HIG(QT_TR_NOOP("No frames to encode"),QT_TR_NOOP("Please check markers. Is \"A>\" == \">B\"?"));
@@ -1575,23 +1578,23 @@ A_saveAudioDecodedTest (char *name)
       //      printf("Got : %lu\n",len2);
       gauge += len;
       sampleCurrent+=samples;
-      // update GUI                   
+      // update GUI
 	// JSC: if "A>" == ">B" we will get >100% here => assert in work->update()
 	if (work->update ((sampleCurrent>>10 > sampleTarget>>10 ? sampleTarget>>10 : sampleCurrent>>10), sampleTarget>>10))	// abort request ?
 	    break;;
-      if (gauge > OUTCHUNK)	// either out buffer is full	
+      if (gauge > OUTCHUNK)	// either out buffer is full
 	{
-	  fwrite (outbuffer, 1, gauge, out);	  
+	  fwrite (outbuffer, 1, gauge, out);
 	  written += gauge;
 	  gauge = 0;
-	}   	
+	}
     };
 // Clean up
 	if(gauge)
 	{
-		fwrite (outbuffer,  gauge,1, out);	  
+		fwrite (outbuffer,  gauge,1, out);
 		written += gauge;
-		gauge = 0;	
+		gauge = 0;
 	}
   saveFilter->endWrite (out, written);
   fclose (out);
@@ -1725,7 +1728,7 @@ uint8_t ADM_saveRaw (const char *name)
                 }
                 ADM_assert (video_body->getFlags (i, &flags));
         }
-      
+
       if (flags & AVI_B_FRAME)	// oops
 	{
 	  // se search for the next i /p
@@ -1778,7 +1781,7 @@ _abt:
 }
 
 void
-A_saveWorkbench (char *name)
+A_saveWorkbench (const char *name)
 {
 #if 0
   video_body->saveWorbench (name);
@@ -1910,7 +1913,7 @@ uint32_t count;
       aviInfo info;
       ADM_assert (video_body->getVideoInfo (&info));
       count = end - start;
-     
+
       if( end < start ){
         GUI_Error_HIG(QT_TR_NOOP("Marker A > B"), QT_TR_NOOP("Cannot delete the selection."));
          return 0;
@@ -1933,7 +1936,7 @@ uint32_t count;
 	{
           GUI_Error_HIG (QT_TR_NOOP("Something bad happened (II)"), NULL);
 	}
-      
+
 
 
       frameEnd=avifileinfo->nb_frames-1;
@@ -1942,7 +1945,7 @@ uint32_t count;
       UI_setMarkers (frameStart, frameEnd);
       ReSync ();
      return 1;
-      
+
 
 
 }
@@ -1958,7 +1961,7 @@ uint32_t frame;
                 return 0;
         }
         return GUI_GoToFrame(frame);
-        
+
 }
 
 //
@@ -1966,7 +1969,7 @@ void	A_setPostproc( void )
 {
 uint32_t type,strength,swap;
 	if(!avifileinfo) return;
-	
+
 	video_body->getPostProc(&type,&strength,&swap);
 
  	if(DIA_getMPParams( &type, &strength,&swap))
@@ -1985,8 +1988,8 @@ void A_audioTrack( void )
 {
         uint32_t nb;
         audioInfo *infos=NULL;
-        
-        uint32_t old,nw;        
+
+        uint32_t old,nw;
         uint8_t r=0;
         uint32_t oldtrack,newtrack;
         char *newtrackname=ADM_strdup(currentAudioName);
@@ -1998,7 +2001,7 @@ void A_audioTrack( void )
         }
         newtrack=oldtrack=(uint32_t)video_body->getCurrentAudioStreamNumber(0);
         nw=old=currentAudioSource;
-        
+
         /* Build dialog factory widget */
         diaMenuEntry sourcesStream[]={
             {AudioAvi,QT_TR_NOOP("Video"),QT_TR_NOOP("Take audio from video file")},
@@ -2007,14 +2010,14 @@ void A_audioTrack( void )
             {AudioMP3,QT_TR_NOOP("External MP3"),QT_TR_NOOP("Take audio from external MP3 file")},
             {AudioWav,QT_TR_NOOP("External WAV"),QT_TR_NOOP("Take audio from external WAV file")}
         };
-        
-        
+
+
         diaElemMenu   sourceMenu(&nw,QT_TR_NOOP("_Audio source:"),5,sourcesStream,NULL);
-        
-        
-        
+
+
+
         diaElemFile  sourceName(0,&newtrackname,QT_TR_NOOP("_External file:"), NULL, QT_TR_NOOP("Select file"));
-        
+
         // Now build the list of embedded track
 #define MAX_AUDIO_TRACK 10
 #define MAX_AUDIO_TRACK_NAME 100
@@ -2027,24 +2030,24 @@ void A_audioTrack( void )
            sourceavitracks[i]=new diaMenuEntryDynamic(i,string,NULL);
         }
          if(infos) delete [] infos;
-         
+
          diaElemMenuDynamic   sourceFromVideo(&newtrack,QT_TR_NOOP("_Track from video:"),nb,sourceavitracks);
          diaElem *allWidgets[]={&sourceMenu,&sourceFromVideo,&sourceName};
-         
+
          /* Link..*/
          sourceMenu.link(&(sourcesStream[0]),1,&sourceFromVideo);
          sourceMenu.link(&(sourcesStream[2]),1,&sourceName);
          sourceMenu.link(&(sourcesStream[3]),1,&sourceName);
          sourceMenu.link(&(sourcesStream[4]),1,&sourceName);
-         
-         
+
+
          if( diaFactoryRun(QT_TR_NOOP("Main Audio Track"),3,allWidgets))
          {
            if(nw!=AudioNone && nw!=AudioAvi)
            {
               if( !ADM_fileExist(newtrackname))
               {
-                GUI_Info_HIG(ADM_LOG_INFO,QT_TR_NOOP("Cannot load"),QT_TR_NOOP("The selected audio file does not exist.")); 
+                GUI_Info_HIG(ADM_LOG_INFO,QT_TR_NOOP("Cannot load"),QT_TR_NOOP("The selected audio file does not exist."));
                 goto roger_and_out;
               }
            }
@@ -2083,7 +2086,7 @@ void A_audioTrack( void )
                             ADM_assert(0);
         }
          }
-roger_and_out:         
+roger_and_out:
          /* Clean up */
          for(int i=0;i<nb;i++)
             delete sourceavitracks[i];
@@ -2106,7 +2109,7 @@ void A_externalAudioTrack( void )
             {AudioMP3,QT_TR_NOOP("External MP3"),QT_TR_NOOP("Take audio from external MP3 file")},
             {AudioWav,QT_TR_NOOP("External WAV"),QT_TR_NOOP("Take audio from external WAV file")}
         };
-        
+
         old=nw=secondAudioSource;
 
         diaElemMenu     sourceMenu(&nw,QT_TR_NOOP("_Audio source:"),4,sourcesStream,NULL);
@@ -2114,7 +2117,7 @@ void A_externalAudioTrack( void )
         diaElem *allWidgets[]={&sourceMenu,&sourceName};
 
   /* Link..*/
-        
+
          sourceMenu.link(&(sourcesStream[2]),1,&sourceName);
          sourceMenu.link(&(sourcesStream[3]),1,&sourceName);
          sourceMenu.link(&(sourcesStream[1]),1,&sourceName);
@@ -2152,11 +2155,11 @@ uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name)
                         {
                                 delete tmp;
                                 GUI_Error_HIG(QT_TR_NOOP("Error loading the MP3 file"), NULL);
-                                
+
                         }
                         else
                         {
-                                secondaudiostream = tmp;     
+                                secondaudiostream = tmp;
                                 secondAudioSource=AudioMP3;
                                 secondAudioName=ADM_strdup(name);
                                 printf ("\n MP3 loaded\n");
@@ -2178,7 +2181,7 @@ uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name)
                         }
                         else
                         {
-                                secondaudiostream = tmp;     
+                                secondaudiostream = tmp;
                                 secondAudioSource=AudioAC3;
                                 secondAudioName=ADM_strdup(name);
                                 printf ("\n AC3 loaded\n");
@@ -2200,7 +2203,7 @@ uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name)
                         }
                         else
                         {
-                                secondaudiostream = tmp;     
+                                secondaudiostream = tmp;
                                 secondAudioSource=AudioAC3;
                                 secondAudioName=ADM_strdup(name);
                                 printf ("\n AC3 loaded\n");
@@ -2213,7 +2216,7 @@ uint8_t A_setSecondAudioTrack(const AudioSource nw,char *name)
         }
         return 0;
 }
-             
+
 
 //****************
 uint8_t A_TimeShift(void)
@@ -2239,7 +2242,7 @@ void A_Resync(void)
 // Just in case update file info
         if(!avifileinfo) return;
         rebuild_status_bar();
-        
+
         if(curframe>avifileinfo->nb_frames) curframe=frameEnd;
         UI_setMarkers (frameStart, frameEnd);
         GUI_GoToFrame(curframe);
@@ -2247,7 +2250,7 @@ void A_Resync(void)
 uint8_t  DIA_job_select(char **jobname, char **filename);
 void A_addJob(void)
 {
-        char *name,*fullname,*base,*final=NULL;
+        char *name=NULL,*fullname,*base,*final=NULL;
 
         if(!DIA_job_select(&name,&final)) return;
         if(!name || !final) return;
@@ -2255,7 +2258,7 @@ void A_addJob(void)
 
         base=ADM_getJobDir();
         fullname=new char[strlen(name)+strlen(base)+2+4];
-        
+
         strcpy(fullname,base);
         strcat(fullname,"/");
         strcat(fullname,name);
@@ -2313,7 +2316,7 @@ uint32_t GUI_GetScale(void)
 
     percent = UI_readScale();
     tg= (avifileinfo->nb_frames-1) * percent / 100.;
-    
+
     return (uint32_t)floor(tg);;
 
 
@@ -2332,20 +2335,20 @@ void  update_status_bar(void)
 
     //    if(!guiReady) return ;
     text[0] = 0;
- 
+
 	UI_updateFrameCount( curframe);
 	UI_updateTimeCount( curframe,avifileinfo->fps1000);
-       
+
     // progress bar
     len = 100;
     if(avifileinfo->nb_frames>1)
     	len=len / (double) (avifileinfo->nb_frames-1);
     len *= (double) curframe;
 
-   
+
 
      UI_setScale(len);
-   	
+
 }
 
 ///
@@ -2359,10 +2362,10 @@ void rebuild_status_bar(void)
 
     //    if(!guiReady) return ;
     text[0] = 0;
- 
+
 	UI_setFrameCount( curframe, avifileinfo->nb_frames);
 	UI_setTimeCount( curframe, avifileinfo->nb_frames,avifileinfo->fps1000);
-	
+
     // progress bar
     len = 100;
     if(avifileinfo->nb_frames>1)
@@ -2382,7 +2385,7 @@ uint8_t GUI_getFrameContent(ADMImage *image, uint32_t frame)
 {
   uint32_t flags;
   if(!video_body->getUncompressedFrame(frame,image,&flags)) return 0;
-  return 1; 
+  return 1;
 }
 /**
     \fn GUI_close
@@ -2393,6 +2396,7 @@ uint8_t GUI_close(void)
   if (avifileinfo)		// already opened ?
     {				// delete everything
       // if preview is on
+      admPreview::setMainDimension(0, 0);
       if(getPreviewMode()!=ADM_PREVIEW_NONE)
       {
 	admPreview::stop();
@@ -2400,8 +2404,8 @@ uint8_t GUI_close(void)
       }
       delete avifileinfo;
       //delete wavinfo;
-      wavinfo = (WAVHeader *) NULL;
-      avifileinfo = (aviInfo *) NULL;
+      wavinfo = NULL;
+      avifileinfo = NULL;
       video_body->cleanup ();
       curframe = 0;
       A_changeAudioStream (NULL, AudioNone,NULL);
@@ -2416,6 +2420,8 @@ uint8_t GUI_close(void)
 	  secondaudiostream=NULL;
 
       filterCleanUp ();
+	  UI_setTitle(NULL);
+
       return 1;
     }
     return 0;
@@ -2461,25 +2467,25 @@ void GUI_showCurrentFrameHex(void)
  uint32_t fullLen,flags;
  char sType[5];
  char sSize[15];
- 
+
  if (!avifileinfo) return;
- 
+
  buffer=new uint8_t [avifileinfo->width*avifileinfo->height*3];
- video_body->getRaw (curframe, buffer, &fullLen);  
+ video_body->getRaw (curframe, buffer, &fullLen);
  video_body->getFlags (curframe, &flags);
- 
+
  diaElemHex binhex("*****",fullLen,buffer);
-      
+
  if(flags==AVI_KEY_FRAME) sprintf(sType,"I");
   else if(flags==AVI_B_FRAME) sprintf(sType,"B");
     else sprintf(sType,"P");
  sprintf(sSize,"%d bytes",fullLen);
- 
+
  diaElemReadOnlyText Type(sType,QT_TR_NOOP("Frame type:"));
  diaElemReadOnlyText Size(sSize,QT_TR_NOOP("Frame size:"));
  diaElem *elems[]={&Type,&Size,&binhex   };
  if(diaFactoryRun(QT_TR_NOOP("Frame Hex Dump"),3,elems))
- 
+
  delete [] buffer;
 }
 
