@@ -18,19 +18,11 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
+//#include "default.h" // avi_vars.h includes this
+#include "avi_vars.h"
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <math.h>
 
-
-#include "callbacks.h"
-#include "interface.h"
-#include "support.h"
-
-#include "fourcc.h"
-#include "avi_vars.h"
 #include "ADM_toolkit/filesel.h"
 
 #include "ADM_assert.h"
@@ -41,53 +33,53 @@
 #include "ADM_audiofilter/audioprocess.hxx"
 #include "gui_action.hxx"
 #include "gtkgui.h"
-#include "gui_action.hxx"
 #include "ADM_toolkit/toolkit.hxx"
-#include "ADM_toolkit/toolkit_gtk.h"
-#include "ADM_gui2/GUI_render.h"
-#include "ADM_dialog/DIA_working.h"
+//#include "ADM_toolkit/toolkit_gtk.h"
+#include "GUI_render.h"
+#include "DIA_working.h"
 #include "ADM_video/ADM_genvideo.hxx"
 #include "ADM_filter/video_filters.h"
+#include "DIA_busy.h"
+#include "GUI_ui.h"
+extern void    UI_purge(void );
 //____________________________________
 
-uint8_t GUI_getFrame(uint32_t frameno, ADMImage *image, uint32_t *flags)
+uint8_t GUI_getFrame(uint32_t frameno,  uint32_t *flags)
 {
 uint32_t len;
 
 	//return video_body->getUncompressedFrame(frameno,image,flags);
 	AVDMGenericVideoStream *filter=getFirstCurrentVideoFilter( );
 	ADM_assert(filter);
-	return filter->getFrameNumberNoAlloc(frameno,&len,image,flags);
-	
+	return 1;
+
 
 }
-void GUI_NextFrame(void)
+void GUI_NextFrame(uint32_t frameCount)
 {
 //    uint8_t *ptr;
 uint32_t flags;
     if (playing)
 	return;
 
-    if( avifileinfo && curframe + 1 == avifileinfo->nb_frames )
+    if( avifileinfo && curframe + frameCount >= avifileinfo->nb_frames )
 	return;
 
     if (avifileinfo)
       {
-        if( !GUI_getFrame(curframe + 1,rdr_decomp_buffer,&flags))
+        uint32_t newframe = curframe + frameCount;
+        if( !GUI_getFrame(newframe,&flags))
         	{
-                  GUI_Error_HIG(_("Decompressing error"),_( "Cannot decode next frame."));
+                  GUI_Error_HIG(QT_TR_NOOP("Decompressing error"),QT_TR_NOOP( "Cannot decode next frame."));
            	}
            else
-           {
-		curframe++;
-               	if(mode_preview)
-          			editorUpdatePreview( curframe) ;
-						
-		renderUpdateImage(rdr_decomp_buffer->data);
-     		 update_status_bar(rdr_decomp_buffer);
-
-		UI_purge();
-	  	}
+            {
+                  curframe = newframe;
+                  admPreview::update( curframe) ;
+                  update_status_bar();
+  
+                UI_purge();
+            }
      }
 }
 
@@ -113,18 +105,15 @@ void GUI_NextKeyFrame(void)
            	}
 		else
 		{
-			curframe=f;
-			if( !GUI_getFrame(curframe,rdr_decomp_buffer,&flags))
-        		{
-                          GUI_Error_HIG(_("Decompressing error"),_( "Cannot decode keyframe."));
-			}
-			
-			renderUpdateImage(rdr_decomp_buffer->data);
-			if(mode_preview)
-         				editorUpdatePreview( curframe)     ;
-
-			update_status_bar(rdr_decomp_buffer);
-			UI_purge();
+                        curframe=f;
+                        if( !GUI_getFrame(curframe,&flags))
+                        {
+                          GUI_Error_HIG(QT_TR_NOOP("Decompressing error"),QT_TR_NOOP( "Cannot decode keyframe."));
+                        }
+                        
+                        admPreview::update( curframe) ;
+                        update_status_bar();
+                        UI_purge();
 		}
 		
   	}
@@ -141,6 +130,11 @@ uint8_t  countLightPixels(int darkness)
     uint32_t sz = width * height ;
     const int maxnonb=(width* height)>>8;
 
+    return 0;
+#warning FIXME
+#warning FIXME
+#warning FIXME
+#if 0
     uint8_t *buff;
 
     int cnt4=0;
@@ -154,7 +148,7 @@ uint8_t  countLightPixels(int darkness)
 	if(cnt4>=maxnonb)
 	  return(1);
     }
-
+#endif
     return(0);
 }
 //**********************************************************************
@@ -164,21 +158,23 @@ uint8_t  countLightPixels(int darkness)
 //**********************************************************************
 
 static const int  sliceOrder[8]={3,4,2,5,1,6,0,7};
-
-static int sliceScanNotBlack(int darkness, int maxnonb, int sliceNum)
+/**
+        \fn sliceScanNotBlack
+        \brief The image is split into 8 slices, returns if the given slice is black or not
+*/
+static int sliceScanNotBlack(int darkness, int maxnonb, int sliceNum,ADMImage *img)
 {
 
-{
 
-    uint32_t width = avifileinfo->width;
-    uint32_t height = avifileinfo->height>>3;
+    uint32_t width = img->_width;
+    uint32_t height = img->_height>>3;
     uint32_t sz = width * height ;    
 
     uint8_t *buff,*start;
 
     int cnt4=0;
 
-    start=rdr_decomp_buffer->data+ sz*sliceNum;
+    start=img->data+ sz*sliceNum;
     buff=start+sz;
 
     while(--buff>start)
@@ -190,16 +186,18 @@ static int sliceScanNotBlack(int darkness, int maxnonb, int sliceNum)
           return(1);
       }
     }
-    //printf("Slice : %d count:%d max:%d\n",sliceNum,cnt4,maxnonb);
     return(0);
-}
 
 }
-uint8_t  fastIsNotBlack(int darkness)
+/**
+    \fn fastIsNotBlack
+    \brief Quickly check if the frame is black or not
+*/
+uint8_t  fastIsNotBlack(int darkness,ADMImage *img)
 {
 
-    uint32_t width = avifileinfo->width;
-    uint32_t height = avifileinfo->height;    
+    uint32_t width = img->_width;
+    uint32_t height = img->_height;    
     uint32_t maxnonb=(width* height)>>8;
     
         maxnonb>>=3;
@@ -207,11 +205,11 @@ uint8_t  fastIsNotBlack(int darkness)
         // Scan 2 & 3 first, if still good, go on
         for(uint32_t i=0;i<6;i++)
         {
-                if(sliceScanNotBlack(darkness,maxnonb,sliceOrder[i])) return 1;
+                if(sliceScanNotBlack(darkness,maxnonb,sliceOrder[i],img)) return 1;
         }
         // The slice 0 & 7 are particular and we admit twice as much
-        if(sliceScanNotBlack(darkness,maxnonb*2,0)) return 1;
-        if(sliceScanNotBlack(darkness,maxnonb*2,7)) return 1;
+        if(sliceScanNotBlack(darkness,maxnonb*2,0,img)) return 1;
+        if(sliceScanNotBlack(darkness,maxnonb*2,7,img)) return 1;
 
     return(0);
 }
@@ -225,26 +223,32 @@ void GUI_NextPrevBlackFrame(int dir)
    uint32_t flags;
    uint16_t reresh_count=0;
    uint32_t orgFrame;
-   uint32_t r=1; 
-
-    if (playing)
+   uint32_t r=1;
+  if (playing)
 		return;
     if (! avifileinfo)
        return;
 
+    ADMImage *buffer=admPreview::getBuffer();
+    if(!buffer) return;
+
    const int darkness=40;
 
-   DIA_working *work=new DIA_working("Seeking");
+   DIA_working *work=new DIA_working(QT_TR_NOOP("Seeking"));
    orgFrame=curframe;
+   int total;
+    // Avoid it being 0
+    if(dir=1) total=avifileinfo->nb_frames-curframe+1;
+        else total=curframe+1;
    while(1)
    {
-
+        int current=abs(curframe-orgFrame);
       f=curframe+dir;
-      if(work->update(f,avifileinfo->nb_frames)) break;
+      if(work->update(current,total)) break;
 
       if((f==0 && dir==-1)|| (f==avifileinfo->nb_frames-1&&dir==1)) break;
 
-     if( !video_body->getUncompressedFrame(f ,rdr_decomp_buffer,&flags))
+     if( !video_body->getUncompressedFrame(f ,buffer,&flags))
        {
           r=0;
           break;
@@ -256,11 +260,11 @@ void GUI_NextPrevBlackFrame(int dir)
     }
         curframe=f;
 
-        if(!fastIsNotBlack(darkness)) break;
+        if(!fastIsNotBlack(darkness,buffer)) break;
         reresh_count++;
         if(reresh_count>100)
         {
-                update_status_bar(rdr_decomp_buffer);
+                update_status_bar();
                 reresh_count=0;
         }       
    }
@@ -268,19 +272,18 @@ void GUI_NextPrevBlackFrame(int dir)
    if(!r)
    {
       curframe=orgFrame;
-      video_body->getUncompressedFrame(orgFrame ,rdr_decomp_buffer);
    }
-   renderUpdateImage(rdr_decomp_buffer->data);
-   if(mode_preview)
-	 editorUpdatePreview( curframe)     ;
-   update_status_bar(rdr_decomp_buffer);
+    admPreview::update( curframe) ;
+    update_status_bar();
 
    return ;
 }
+/**
+    \fn A_ListAllBlackFrames
+    \brief Scan for all black frames and output that in a separate (text) file
+*/
 uint8_t A_ListAllBlackFrames(char *name)
 {
-// Print a list of all black frames
-//_____________________________________________________________
     uint32_t f;
     uint32_t flags;
     uint32_t startframe;
@@ -297,7 +300,8 @@ uint8_t A_ListAllBlackFrames(char *name)
         return 0;
     if ( !avifileinfo )
         return 0;
-
+   ADMImage *buffer=admPreview::getBuffer();
+    if(!buffer) return 0;
    
     if ( !outfile )
         return 0;
@@ -311,20 +315,20 @@ uint8_t A_ListAllBlackFrames(char *name)
     const int darkness=40;
 
     startframe=curframe;
-    DIA_working *work=new DIA_working("Finding black frames");
+    DIA_working *work=new DIA_working(QT_TR_NOOP("Finding black frames"));
     printf("\n** Listing all black frames **\n");
 
     for (f=0; f<avifileinfo->nb_frames; f++) {
        if( work->update( 100 * f / avifileinfo->nb_frames ) ) 
             break;
-        if ( !video_body->getUncompressedFrame(f,rdr_decomp_buffer,&flags) ) {
-            curframe=0;
-            video_body->getUncompressedFrame(0,rdr_decomp_buffer);
+        if ( !video_body->getUncompressedFrame(f,buffer,&flags) ) 
+        {
             break;
         }
 
         curframe=f;
-        if ( !fastIsNotBlack(darkness) ) {
+        if ( !fastIsNotBlack(darkness,buffer) ) 
+        {
             frame2time(curframe,avifileinfo->fps1000,&hh,&mm,&ss,&ms);
             printf("\tBlack frame: frame %d  time %02d:%02d:%02d.%03d\n", curframe, hh, mm, ss, ms);
             fprintf(fd, "\tBlack frame: frame %d  time %02d:%02d:%02d.%03d\n", curframe, hh, mm, ss, ms);
@@ -332,7 +336,7 @@ uint8_t A_ListAllBlackFrames(char *name)
         reresh_count++;
         if(reresh_count>100)
         {
-                update_status_bar(rdr_decomp_buffer);
+                update_status_bar();
                 reresh_count=0;
         }
     }
@@ -340,16 +344,7 @@ uint8_t A_ListAllBlackFrames(char *name)
     printf("** done **\n\n");
     fclose(fd);
     delete work;
-    curframe=startframe;
-    if ( !video_body->getUncompressedFrame(curframe,rdr_decomp_buffer,&flags) ) {
-        curframe=0;
-        video_body->getUncompressedFrame(0,rdr_decomp_buffer);
-    }
-    renderUpdateImage(rdr_decomp_buffer->data);
-    if ( mode_preview )
-        editorUpdatePreview( curframe );
-    update_status_bar(rdr_decomp_buffer);
-
+    GUI_GoToFrame(startframe);
     return 1;
 }
 //**********************************************************************
@@ -361,18 +356,23 @@ uint8_t A_ListAllBlackFrames(char *name)
 void GUI_GoToKFrame(uint32_t frame)
 {
    uint32_t old=curframe;
-//  uint32_t flags;
 
-        if (playing)
-				return;
 
-	if (avifileinfo)
-	{
-		// curframe=frame;
-		//
-		curframe=frame;
-		GUI_PreviousKeyFrame();	
-     	}
+    if (playing)
+            return;
+
+    if (avifileinfo)
+    {
+        if(frame>=avifileinfo->nb_frames)
+        {
+            curframe=avifileinfo->nb_frames-1;
+        }
+        else
+        {
+            curframe=frame;
+            GUI_PreviousKeyFrame();	
+        }
+    }
 }
 
 //_____________________________________________________________
@@ -380,30 +380,26 @@ int GUI_GoToFrame(uint32_t frame)
 {
 uint32_t flags;
 
-	if (playing)
-		return 0;
+      if (playing)
+              return 0;
 
-      if (!avifileinfo)
-      		return 0;
+    if (!avifileinfo)
+              return 0;
+    
+      if(frame>=avifileinfo->nb_frames) return 0;
+
+      if( !GUI_getFrame(frame ,&flags))
+      {
+        GUI_Error_HIG(QT_TR_NOOP("Decompressing error"),QT_TR_NOOP( "Cannot decode the frame."));
+              return 0;
+      }
+        
+      curframe = frame;
+      admPreview::update( curframe) ;
+      update_status_bar();
+      UI_purge();
       
-
-	if( !GUI_getFrame(frame ,rdr_decomp_buffer,&flags))
-	{
-          GUI_Error_HIG(_("Decompressing error"),_( "Cannot decode the frame."));
-		return 0;
-	}
-
-	curframe = frame;
-	renderUpdateImage(rdr_decomp_buffer->data);
-
-	if(mode_preview)
-		editorUpdatePreview( curframe);
-
-	update_status_bar(rdr_decomp_buffer);
-	UI_purge();
-	
-    	return 1;
-
+      return 1;
 }
 
 
@@ -421,27 +417,24 @@ void GUI_PreviousKeyFrame(void)
     f=curframe;
     if (avifileinfo)
       {
-		if(!video_body->getPKFrame(&f)&&curframe)
-		//if( !GUI_getFrameNKF(&f ,rdr_decomp_buffer))
-        	{
-            //	GUI_Error_HIG("Decompressing error", NULL);
-           	}
-		else
-		{
-			curframe=f;
-			if( !GUI_getFrame(curframe,rdr_decomp_buffer,&flags))
-        		{
-                          GUI_Error_HIG(_("Decompressing error"),_( "Cannot decode keyframe."));
-			}
-			
-			renderUpdateImage(rdr_decomp_buffer->data);
-			if(mode_preview)
-         				editorUpdatePreview( curframe)     ;
+            if(!video_body->getPKFrame(&f)&&curframe)
+            {
+                  return;
+            }
+            else
+            {
+                    curframe=f;
+                    if( !GUI_getFrame(curframe,&flags))
+                    {
+                      GUI_Error_HIG(QT_TR_NOOP("Decompressing error"),QT_TR_NOOP( "Cannot decode keyframe."));
+                    }
+                    
+                    admPreview::update( curframe) ;
 
-			update_status_bar(rdr_decomp_buffer);
-			UI_purge();
-		}
-		
+                    update_status_bar();
+                    UI_purge();
+            }
+              
   	}
 };
 
@@ -449,4 +442,79 @@ uint8_t A_rebuildKeyFrame(void)
 {
 
         return video_body->rebuildFrameType();
-}
\ No newline at end of file
+}
+/**
+    \fn GUI_PrevFrame
+    \brief Go to current frame -1
+*/
+void        GUI_PrevFrame(uint32_t frameCount)
+{
+      if (int (curframe) - int (frameCount) >= 0)
+        {
+          
+          // DIA_StartBusy ();
+          GUI_GoToFrame (curframe - frameCount);
+          // DIA_StopBusy ();
+        }
+}
+/**
+      \fn A_jogRead
+      \brief read an average value of jog
+*/
+#define NB_JOG_READ           3
+#define JOG_READ_PERIOD_US    5*1000 // 5ms
+#define JOG_THRESH1           40
+#define JOG_THRESH2           80
+#define JOG_THRESH1_PERIOD    100*1000 //us
+#define JOG_THRESH2_PERIOD    40*1000
+#define JOG_THRESH3_PERIOD    500
+/**
+    \fn A_jogRead
+    \brief Read an average value of jog
+*/
+uint32_t A_jogRead(void)
+{
+  int32_t sum=0,v;
+    for(int i=0;i<NB_JOG_READ;i++)
+    {
+        v=UI_readJog();
+        if(abs(v)<10) v=0;
+        sum+=v;
+        ADM_usleep(JOG_READ_PERIOD_US);
+    } 
+    return sum/NB_JOG_READ;
+}
+#define REFRESH 10000
+/**
+      \fn     A_jog
+      \brief  Handle jogshuttle widget
+*/
+void A_jog(void)
+{
+  int32_t r;
+  uint32_t a;
+  uint32_t slip;
+  static int jog=0;
+  if(jog) return;
+  jog++;
+  while(r=A_jogRead())
+  {
+      a=abs(r);
+      printf("%d \n",r);
+      if(a<JOG_THRESH1) slip=JOG_THRESH1_PERIOD;
+        else if(a<JOG_THRESH2) slip=JOG_THRESH2_PERIOD;
+          else slip=JOG_THRESH3_PERIOD;
+    
+      if(r>0) GUI_NextKeyFrame();
+      else GUI_PreviousKeyFrame();       
+      UI_purge();
+      for(int i=0;i<slip/REFRESH;i++)
+      {
+        UI_purge();
+        ADM_usleep(REFRESH);
+        UI_purge();
+      }
+  }
+  jog--;
+}
+//EOF
