@@ -38,13 +38,14 @@
 #include "ADM_audiofilter/audioprocess.hxx"
 
 #include "ADM_video/ADM_genvideo.hxx"
-#include "ADM_codecs/ADM_divxEncode.h"
+//#include "ADM_codecs/ADM_divxEncode.h"
 #include "ADM_encoder/ADM_vidEncode.hxx"
 
 #include "oplug_avi/op_aviwrite.hxx"
 #include "oplug_avi/op_avisave.h"
 #include "oplug_avi/op_savecopy.h"
 #include "oplug_mp4/oplug_mp4.h"
+#include "oplug_flv/oplug_flv.h"
 #include "ADM_encoder/adm_encoder.h"
 
 #include "oplug_avi/op_saveprocess.h"
@@ -52,11 +53,13 @@
 #include "ADM_filter/video_filters.h"
 
 #include "ADM_toolkit/filesel.h"
-#include "ADM_gui2/GUI_ui.h"
+#include "GUI_ui.h"
 #include "oplug_mpegFF/oplug_vcdff.h"
 
 static uint8_t  A_SaveAudioNVideo(const char *name);
  extern int A_SaveUnpackedVop(const char *name);
+ extern uint8_t oplug_dummy(const char *name);
+ extern int A_SavePackedVop(const char *name);
  extern uint8_t ogmSave(const char *name);
  extern uint8_t ADM_saveRaw(const char *name);
  uint8_t A_SaveAudioDualAudio(const char *name);
@@ -83,7 +86,7 @@ int ret=0;
         {
                 if(UI_GetCurrentFormat()==ADM_AVI_DUAL)
                 {
-                  GUI_Error_HIG(_("Dual audio can only be used in copy mode"),_( "Select Copy as the video codec."));
+                  GUI_Error_HIG(QT_TR_NOOP("Dual audio can only be used in copy mode"),QT_TR_NOOP( "Select Copy as the video codec."));
                         return 0;
                 }
         }
@@ -169,8 +172,16 @@ int ret=0;
 					printf(" AVI family\n");
 					switch(UI_GetCurrentFormat())
 					{
-                                                case ADM_MP4:
-                                                case ADM_PSP:
+						case ADM_DUMMY:
+					                            			ret=oplug_dummy(name);
+					                            			break;
+						case ADM_FLV:
+                            			ret=oplug_flv(name);
+                            			break;
+                        case ADM_MP4:
+                        case ADM_PSP:
+                        case ADM_MATROSKA:
+                        
                                                     ret=oplug_mp4(name,UI_GetCurrentFormat());
                                                     break;
 						case ADM_AVI:
@@ -185,11 +196,15 @@ int ret=0;
 						case ADM_AVI_DUAL:
 								ret=A_SaveAudioDualAudio(name);
 								break;
+                                                case ADM_AVI_PAK:
+								ret=A_SavePackedVop(name);
+								break;
+
 						case ADM_AVI_UNP:
 								ret=A_SaveUnpackedVop(name);
 								break;
 						default:
-                                                  GUI_Error_HIG(_("Incompatible output format"), NULL);
+                                                  GUI_Error_HIG(QT_TR_NOOP("Incompatible output format"), NULL);
 					}
 					break;
 		case CodecFamilyMpeg:
@@ -205,7 +220,7 @@ int ret=0;
 						          ret=mpeg_passthrough(name,UI_GetCurrentFormat());
                                                           break;
                                                   default:
-                                                    GUI_Error_HIG(_("Incompatible output format"), NULL);
+                                                    GUI_Error_HIG(QT_TR_NOOP("Incompatible output format"), NULL);
                                                 }
                                                 break;
                                         } // THERE IS NO BREAK HERE, NOT A MISTAKE!
@@ -218,7 +233,7 @@ int ret=0;
                                 ret=oplug_mpegff(name,UI_GetCurrentFormat());;
                                 break;
                         default:
-                          GUI_Error_HIG(_("Incompatible output format"), NULL);
+                          GUI_Error_HIG(QT_TR_NOOP("Incompatible output format"), NULL);
                     }
                     break;
                 default:
@@ -236,11 +251,11 @@ uint8_t ret=0;
 
 		if(! secondaudiostream)
 		{
-                  GUI_Error_HIG(_("There is no second track"), _("Select a second audio track in the Audio menu."));
+                  GUI_Error_HIG(QT_TR_NOOP("There is no second track"), QT_TR_NOOP("Select a second audio track in the Audio menu."));
 				  	return 0;
 		}
 		if(!inname)
-                  GUI_FileSelWrite(_("Select dual audio AVI to write"), (char**)& name);
+                  GUI_FileSelWrite(QT_TR_NOOP("Select dual audio AVI to write"), (char**)& name);
 		else
 			name=inname;
 			
@@ -262,11 +277,29 @@ int ret;
 	video_body->getVideoInfo(&info);
 	if( !isMpeg4Compatible(  info.fcc))
 	{
-          GUI_Error_HIG(_("This cannot have packed VOP"),_( "It is not MPEG-4 video. File will not be saved."));
+          GUI_Error_HIG(QT_TR_NOOP("This cannot have packed VOP"),QT_TR_NOOP( "It is not MPEG-4 video. File will not be saved."));
 		return 0;
         }
 	//
-	nw=new   GenericAviSaveCopy(1);
+	nw=new   GenericAviSaveCopyUnpack();
+	ret=nw->saveAvi(name);
+	delete nw;
+	return ret;
+}
+int A_SavePackedVop(const char *name)
+{
+  aviInfo info;
+GenericAviSave	*nw;
+int ret;
+
+	video_body->getVideoInfo(&info);
+	if( !isMpeg4Compatible(  info.fcc))
+	{
+          GUI_Error_HIG(QT_TR_NOOP("This cannot have packed VOP"),QT_TR_NOOP( "It is not MPEG-4 video. File will not be saved."));
+		return 0;
+        }
+	//
+	nw=new   GenericAviSaveCopyPack();
 	ret=nw->saveAvi(name);
 	delete nw;
 	return ret;
@@ -308,10 +341,10 @@ uint8_t  A_SaveAudioNVideo(const char *name)
                   }
                   else
                   {
-                    if(GUI_Question(_("You may need smart copy.\n Enable it ?")))
+                    if(GUI_Question(QT_TR_NOOP("You may need smart copy.\n Enable it ?")))
                     {
                         value=4;
-                        if( ! GUI_getIntegerValue(&value, 2, 31, "Q Factor (set 4)"))
+                        if( ! GUI_getIntegerValue(&value, 2, 31, "_Q factor (set 4):"))
                                       return 0;
                         nw=new   GenericAviSaveSmart(value);
                     }
