@@ -18,7 +18,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include <config.h>
+#include "config.h"
  
 #include <stdio.h>
 #include <stdlib.h>
@@ -26,16 +26,8 @@
 #include <unistd.h>
 #include <errno.h>
 
-
-
-
-
-#include <gtk/gtk.h>
-
 #include "config.h"
-#include "callbacks.h"
-#include "interface.h"
-#include "support.h"
+#include "prefs.h"
 
 #include "fourcc.h"
 #include "avi_vars.h"
@@ -44,18 +36,17 @@
 #include "ADM_toolkit/filesel.h"
 #include "prototype.h"
 #include "ADM_audiodevice/audio_out.h"
-//#include "avdm_mad.h"
 
 #include "ADM_toolkit/toolkit.hxx"
-#include "ADM_toolkit/toolkit_gtk.h"
 #include "ADM_audio/aviaudio.hxx"
 #include "ADM_audiofilter/audioprocess.hxx"
 
 #include "ADM_video/ADM_genvideo.hxx"
 #include "ADM_filter/video_filters.h"
 #include "gtkgui.h"
-#include "ADM_gui2/GUI_render.h"
+#include "GUI_render.h"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
+#include "ADM_libraries/ADM_utilities/avidemutils.h"
 
 //___________________________________
 #define AUDIO_PRELOAD 150
@@ -64,14 +55,11 @@
 static void resetTime(void);
 static void ComputePreload(void);
 static void FillAudio(void);
-
+extern void UI_purge(void);
 #define EVEN(x) (x&0xffffffe)
 
-
- extern void  UI_setPreviewToggleStatus( uint8_t status );
- extern uint8_t GUI_getFrame(uint32_t frameno, ADMImage *image, uint32_t *flags);
 //___________________________________
-extern uint8_t stop_req;
+uint8_t stop_req;
 static int called = 0;
 static uint32_t vids = 0, auds = 0, dauds = 0;
 static int32_t delta;
@@ -94,7 +82,6 @@ void GUI_PlayAvi(void)
 
     uint32_t framelen,flags;
     AVDMGenericVideoStream *filter;
-    ADMImage *buffer=NULL;
 
     vids = 0, auds = 0, dauds = 0;
     // check we got everything...
@@ -112,41 +99,36 @@ void GUI_PlayAvi(void)
         stop_req = 1;
         return;
       }
+
+	uint32_t priorityLevel;
+
+	originalPriority = getpriority(PRIO_PROCESS, 0);
+	prefs->get(PRIORITY_PLAYBACK,&priorityLevel);
+	setpriority(PRIO_PROCESS, 0, ADM_getNiceValue(priorityLevel));
+
   uint32_t played_frame=0;
   uint32_t remaining=avifileinfo->nb_frames-curframe;
 
-
-    if(guiOutputDisplay)
+    
+    if(getPreviewMode()==ADM_PREVIEW_OUTPUT)
     {
-                filter=getLastVideoFilter(curframe,remaining);
-                if(mode_preview)
-                {
-                      editorKillPreview ();
-                      UI_setPreviewToggleStatus( 0 );
-                      mode_preview=0;
-                }
+            filter=getLastVideoFilter(curframe,remaining);
     }
     else
     {
             filter=getFirstVideoFilter(curframe,remaining );
     }
+    
     max=filter->getInfo()->nb_frames;
 
     // compute how much a frame lasts in ms
     one_frame = (uint32_t) floor(1000.*1000.*10. / filter->getInfo()->fps1000);
     err = one_frame % 10;
     one_frame /= 10; // Duration of a frame in ms, err =leftover in 1/10 ms
-    buffer=new ADMImage(filter->getInfo()->width,filter->getInfo()->height);
+    
     // go to RealTime...    
-    printf(" One frame : %lu, err=%lu ms\n", one_frame, err);
-    // read frame in chunk
-    if(!filter->getFrameNumberNoAlloc(1,&framelen,buffer,&flags))
-    {
-        printf("\n cannot read frame!\n");
-        goto abort_play;
-    }
-      curframe++;
-      played_frame++;
+    printf("One frame : %lu, err=%lu ms\n", one_frame, err);
+    
     // prepare 1st frame
 
     stop_req = 0;
@@ -155,19 +137,18 @@ void GUI_PlayAvi(void)
 #ifdef HAVE_AUDIO
     ComputePreload();
 #endif
-     renderResize(filter->getInfo()->width,filter->getInfo()->height,currentZoom);
-     renderStartPlaying();
+    
+     
+     //renderStartPlaying();
 // reset timer reference
     resetTime();
+    admPreview::deferDisplay(1,curframe);
+    admPreview::update(played_frame);
     do
     {
         vids++;
-        renderUpdateImage(buffer->data);
-        if(mode_preview&&!guiOutputDisplay)
-        {	
-            editorUpdatePreview(played_frame);
-        }
-        update_status_bar(buffer);
+        admPreview::displayNow(played_frame);;
+        update_status_bar();
         if (time_a == 0)
             time_a = getTime(0);
         // mark !
@@ -176,14 +157,11 @@ void GUI_PlayAvi(void)
 
         if((played_frame)>=(max-1))
         {
-            printf("\n End met (%lu  / %lu )\n",played_frame,max);
+            printf("\nEnd met (%lu  / %lu )\n",played_frame,max);
             goto abort_play;
          }
-        if(!filter->getFrameNumberNoAlloc(played_frame+1,&framelen,buffer,&flags))
-        {
-            printf("\n cannot read frame!\n");
-            goto abort_play;
-        }
+        
+        admPreview::update(played_frame+1);;
 	curframe++;
 	played_frame++;
 
@@ -220,7 +198,7 @@ void GUI_PlayAvi(void)
 	    }
      	//
             UI_purge();
-            if(mode_preview)
+            if(getPreviewMode()==ADM_PREVIEW_SEPARATE )
             {
               UI_purge();
               UI_purge(); 
@@ -234,20 +212,15 @@ abort_play:
     // go back to normal display mode
     //____________________________________
     playing = 0;
-	  delete  buffer;
-
-	   renderStopPlaying();
-	   renderResize(avifileinfo->width ,  avifileinfo->height,currentZoom);
+          
 	   getFirstVideoFilter( );
-	   //video_body->getUncompressedFrame(curframe, rdr_decomp_buffer,&flags);
-	   GUI_getFrame(curframe, rdr_decomp_buffer, &flags);
-	   renderUpdateImage(rdr_decomp_buffer->data);
-	   renderRefresh();
-     	   update_status_bar(rdr_decomp_buffer);
-	   if(mode_preview)
-	   {
-		editorUpdatePreview(curframe);
-	   }
+
+           admPreview::deferDisplay(0,0);
+           UI_purge();
+           // Updated by expose ? 
+           admPreview::update(curframe);
+           UI_purge();
+     	   update_status_bar();
 #ifdef HAVE_AUDIO
     if (currentaudiostream)
       {
@@ -260,6 +233,8 @@ abort_play:
       }
 #endif
     // done.
+
+	setpriority(PRIO_PROCESS, 0, originalPriority);
 };
 
 // return time in ms
@@ -370,7 +345,7 @@ void ComputePreload(void)
     channels= playback->getInfo()->channels;
     one_audio_frame = (one_frame * wavinfo->frequency * channels);	// 1000 *nb audio bytes per ms
     one_audio_frame /= 1000; // In elemtary info (float)
-    printf("\n 1 audio frame = %lu bytes (1)", one_audio_frame);
+    printf("1 audio frame = %lu bytes\n", one_audio_frame);
     // 3 sec buffer..               
     wavbuf =  (float *)  ADM_alloc((3 *  channels * wavinfo->frequency*wavinfo->channels));
     ADM_assert(wavbuf);
@@ -381,7 +356,7 @@ void ComputePreload(void)
 
       if (!latency)
       {
-          GUI_Error_HIG(_("Trouble initializing audio device"), NULL);
+          GUI_Error_HIG(QT_TR_NOOP("Trouble initializing audio device"), NULL);
           return;
       }
     // compute preload                      
@@ -405,8 +380,6 @@ void ComputePreload(void)
     audio_available = 1;
 }
 
-//
-// Build audio filters
 
 #endif
 // EOF
